// Originally translated by: Gabucino the Almighty! <gabucino@mplayerhq.hu>
// Send me money/hw/babes!
//... Okay enough of the hw, now send the other two!
//
// Updated by: Gabrov <gabrov@freemail.hu>
// Sync'ed with help_mp-en.h 1.237 (2006. 04. 02.)

// ========================= MPlayer help ===========================

#ifdef HELP_MP_DEFINE_STATIC
static char help_text[]=
"Indts:   mplayer [opcik] [url|tvonal/]fjlnv\n"
"\n"
"Alapvet opcik: (az sszes opci listjhoz lsd a man lapot!)\n"
" -vo <drv[:dev]> videomeghajt s -alegysg kivlasztsa (lista: '-vo help')\n"
" -ao <drv[:dev]> audiomeghajt s -alegysg kivlasztsa (lista: '-ao help')\n"
#ifdef HAVE_VCD
" vcd://<svszm>  lejtszs (S)VCD (super video cd)-svbl, kzvetlenl\n"
#endif
#ifdef USE_DVDREAD
" dvd://<titleno>  a megadott DVD sv lejtszsa, fjl helyett\n"
" -alang/-slang    DVD audio/felirat nyelv kivlasztsa (2 bets orszgkddal)\n"
#endif
" -ss <idpoz>     a megadott (msodperc v. ra:perc:mperc) pozcira tekers\n"
" -nosound         hanglejtszs kikapcsolsa\n"
" -fs              teljeskpernys lejtszs (vagy -vm, -zoom, bvebben lsd man)\n"
" -x <x> -y <y>    felbonts belltsa (-vm vagy -zoom hasznlata esetn)\n"
" -sub <fjl>      felhasznland felirat-fjl megadsa (lsd -subfps, -subdelay)\n"
" -playlist <fjl> lejtszsi lista fjl megadsa\n"
" -vid x -aid y    lejtszand video- (x) s audio- (y) streamek kivlasztsa\n"
" -fps x -srate y  video (x kpkocka/mp) s audio (y Hz) rta megadsa\n"
" -pp <minsg>    kpjavts fokozatainak belltsa (lsd a man lapot)\n"
" -framedrop       kpkockk eldobsnak engedlyezse (lass gpekhez)\n"
"\n"
"Fontosabb billentyk: (a teljes lista a man-ban s nzd meg az input.conf fjlt)\n"
" <-  vagy  ->     10 msodperces htra/elre ugrs\n"
" le vagy fel      1 percnyi htra/elre ugrs\n"
" pgdown v. pgup   10 percnyi htra/elre ugrs\n"
" < vagy >         1 fjllal elre/htra lps a lejtszsi listban\n"
" p vagy SPACE     pillanatllj (brmely billentyre tovbbmegy)\n"
" q vagy ESC       lejtszs vge s kilps\n"
" + vagy -         audio ksleltetse  0.1 msodperccel\n"
" o                OSD-md vltsa:  nincs / keressv / keressv + id\n"
" * vagy /         hanger fel/le\n"
" x vagy z         felirat ksleltetse  0.1 msodperccel\n"
" r vagy t         felirat pozcijnak megvltoztatsa, lsd -vf expand-ot is\n"
"\n"
" * * * A MANPAGE TOVBBI RSZLETEKET, OPCIKAT, BILLENTYKET TARTALMAZ! * * *\n"
"\n";
#endif

#define MSGTR_SamplesWanted "Plda fjlokra van szksgnk ilyen formtummal, hogy jobb legyen a tmogatsa. Ha neked van ilyened, keresd meg a fejlesztket.\n"

// ========================= MPlayer messages ===========================

// mplayer.c: 

#define MSGTR_Exiting "\nKilps...\n"
#define MSGTR_ExitingHow "\nKilps... (%s)\n"
#define MSGTR_Exit_quit "Kilps"
#define MSGTR_Exit_eof "Vge a fjlnak"
#define MSGTR_Exit_error "Vgzetes hiba"
#define MSGTR_IntBySignal "\nAz MPlayer futsa %d-es szignl miatt megszakadt a(z) %s modulban\n"
#define MSGTR_NoHomeDir "Nem tallom a HOME knyvtrat.\n"
#define MSGTR_GetpathProblem "get_path(\"config\") problma\n"
#define MSGTR_CreatingCfgFile "Konfigurcis fjl ltrehozsa: %s\n"
#define MSGTR_CopyCodecsConf "(msold/linkeld az etc/codecs.conf fjlt ~/.mplayer/codecs.conf-ba)\n"
#define MSGTR_BuiltinCodecsConf "Befordtott codecs.conf hasznlata.\n"
#define MSGTR_CantLoadFont "Nem tudom betlteni a kvetkez fontot: %s\n"
#define MSGTR_CantLoadSub "Nem tudom betlteni a feliratot: %s\n"
#define MSGTR_DumpSelectedStreamMissing "dump: VGZETES HIBA: a krt stream nem tallhat!\n"
#define MSGTR_CantOpenDumpfile "Nem tudom megnyitni a dump fjlt!\n"
#define MSGTR_CoreDumped "Kinyomattam a cuccost, jl.\n"
#define MSGTR_FPSnotspecified "Az FPS (kpkocka/mp) rtk nincs megadva, vagy hibs! Hasznld az -fps opcit!\n"
#define MSGTR_TryForceAudioFmtStr "Megprblom a(z) %s audio codec-csaldot hasznlni...\n"
#define MSGTR_CantFindAudioCodec "Nem tallok codecet a(z) 0x%X audio-formtumhoz!\n"
#define MSGTR_RTFMCodecs "Olvasd el a DOCS/HTML/hu/codecs.html fjlt!\n"
#define MSGTR_TryForceVideoFmtStr "Megprblom a(z) %s video codec-csaldot hasznlni...\n"
#define MSGTR_CantFindVideoCodec "Nem tallok codec-et ami megfelel a kivalasztott vo-hoz s 0x%X video-formtumhoz!\n"
#define MSGTR_CannotInitVO "VGZETES HIBA: Nem tudom elindtani a video-meghajtt!\n"
#define MSGTR_CannotInitAO "Nem tudom megnyitni az audio-egysget -> nincs hang.\n"
#define MSGTR_StartPlaying "Lejtszs indtsa...\n"

#define MSGTR_SystemTooSlow "\n\n"\
"         ***************************************\n"\
"         **** A rendszered tl LASS ehhez! ****\n"\
"         ***************************************\n"\
"Lehetsges okok, s megoldsaik:\n"\
"- Legyakrabban : hibs _audio_ meghajt\n"\
"  - Prbld ki az -ao sdl opcit, vagy hasznld az ALSA OSS emulcijt.\n"\
"  - Adj klnbz rtkeket az -autosync opcinak, kezdetnek a 30 megteszi.\n"\
"- Lass videokimenet\n"\
"  - Egy msik -vo meghajt kiprblsa eredmnyre vezethet (a listhoz lsd\n"\
"    -vo help), s/vagy hasznld a -framedrop opcit!\n"\
"- Lass CPU\n"\
"  - Nagy felbonts DivX/DVD lejtszsval ne prblkozz gyenge processzoron!\n"\
"    Esetleg prblj ki lavdopts opcikat, pl.\n"\
"    -vfm ffmpeg -lavdopts lowres=1:fast:skiploopfilter=all.\n"\
"- Hibs fjl\n"\
"  - A -nobps -ni -forceidx -mc 0 opcik kombincival rdemes szrakozni.\n"\
"- Lass mdia (NFS/SMB, DVD, VCD, stb)\n"\
"  - Prbld ki a -cache 8192 opcit.\n"\
"- Taln egy non-interleaved AVI fjlt prblsz -cache opcival lejtszani?\n"\
"  - Hasznld a -nocache opcit.\n"\
"Tuninghoz tippeket a DOCS/HTML/hu/video.html fjlban tallsz.\n"\
"Ha ez sem segt, olvasd el a DOCS/HTML/hu/bugreports.html fjlt.\n\n"

#define MSGTR_NoGui "Az MPlayer grafikus fellet NLKL lett fordtva!\n"
#define MSGTR_GuiNeedsX "Az MPlayer grafikus felletnek X11-re van szksge!\n"
#define MSGTR_Playing "%s lejtszsa\n"
#define MSGTR_NoSound "Audio: nincs hang!!!\n"
#define MSGTR_FPSforced "FPS knyszertve %5.3f  (ftime: %5.3f)\n"
#define MSGTR_CompiledWithRuntimeDetection "Futsidej CPU detektls hasznlata.\n"
#define MSGTR_CompiledWithCPUExtensions "x86-os CPU - a kvetkez kiterjesztsekkel:"
#define MSGTR_AvailableVideoOutputDrivers "Rendelkezsre ll video meghajtk:\n"
#define MSGTR_AvailableAudioOutputDrivers "Rendelkezsre ll audio meghajtk:\n"
#define MSGTR_AvailableAudioCodecs "Rendelkezsre ll audio codec-ek:\n"
#define MSGTR_AvailableVideoCodecs "Rendelkezsre ll video codec-ek:\n"
#define MSGTR_AvailableAudioFm "Rendelkezsre ll (befordtott) audio codec csaldok/meghajtk:\n"
#define MSGTR_AvailableVideoFm "Rendelkezsre ll (befordtott) video codec csaldok/meghajtk:\n"
#define MSGTR_AvailableFsType "A hasznlhat teljeskpernys rteg-mdok:\n"
#define MSGTR_UsingRTCTiming "Linux hardveres RTC idzts hasznlata (%ldHz)\n"
#define MSGTR_CannotReadVideoProperties "Video: tulajdonsgok beolvassa nem lehetsges.\n"
#define MSGTR_NoStreamFound "Nem tallhat stream\n"
#define MSGTR_ErrorInitializingVODevice "Hiba a kivlasztott video_out (-vo) egysg inicializsakor!\n"
#define MSGTR_ForcedVideoCodec "Knyszertett video codec: %s\n"
#define MSGTR_ForcedAudioCodec "Knyszertett audio codec: %s\n"
#define MSGTR_Video_NoVideo "Video: nincs video!!!\n"
#define MSGTR_NotInitializeVOPorVO "\nHIBA: Nem sikerlt a video filterek (-vf) vagy a video kimenet (-vo) inicializlsa!\n"
#define MSGTR_Paused "\n  =====  SZNET  =====\r"
#define MSGTR_PlaylistLoadUnable "\nLejtszsi lista (%s) betltse sikertelen.\n"
#define MSGTR_Exit_SIGILL_RTCpuSel \
"- Az MPlayer egy 'illeglis utastst' hajtott vgre.\n"\
"  Lehet hogy a futsidej CPU detektl kd hibja...\n"\
"  Olvasd el a DOCS/HTML/hu/bugreports.html fjlt!\n"
#define MSGTR_Exit_SIGILL \
"- Az MPlayer egy 'illeglis utastst' hajtott vgre.\n"\
"  Ez akkor trtnik amikor ms CPU-n futtatod az MPlayer-t mint amire a\n"\
"  fordts/optimalizls trtnt.\n"\
"  Ellenrizd!\n"
#define MSGTR_Exit_SIGSEGV_SIGFPE \
"- Az MPlayer rpke flrelpse miatt hiba lpett fel a CPU/FPU/RAM-ban.\n"\
"  Fordtsd jra az MPlayer-t az --enable-debug opcival, s kszts egy\n"\
"  'gdb' backtrace-t. Bvebben: DOCS/HTML/hu/bugreports.html#bugreports_crash.\n"
#define MSGTR_Exit_SIGCRASH \
"- Az MPlayer sszeomlott. Ennek nem lenne szabad megtrtnnie. Az ok lehet\n"\
"  egy hiba az MPlayer kdjban _vagy_ a Te meghajtidban, _vagy_ a gcc-ben.\n"\
"  Ha gy vled hogy ez egy MPlayer hiba, gy olvasd el a\n"\
"  DOCS/HTML/hu/bugreports.html fjlt s kvesd az utastsait! Nem tudunk s\n"\
"  nem fogunk segteni, amg nem szolglsz megfelel informcikkal a hiba\n"\
"  bejelentsekor.\n"
#define MSGTR_LoadingConfig "'%s' konfigurci betltse\n"
#define MSGTR_AddedSubtitleFile "SUB: felirat fjl (%d) hozzadva: %s\n"
#define MSGTR_RemovedSubtitleFile "SUB: felirat fjl (%d) eltvoltva: %s\n"
#define MSGTR_ErrorOpeningOutputFile "Hiba a(z) [%s] fjl rsakor!\n"
#define MSGTR_CommandLine "Parancs sor:"
#define MSGTR_RTCDeviceNotOpenable "%s megnyitsa nem sikerlt: %s (a felhasznl ltal olvashatnak kell lennie.)\n"
#define MSGTR_LinuxRTCInitErrorIrqpSet "Linux RTC inicializlsi hiba az ioctl-ben (rtc_irqp_set %lu): %s\n"
#define MSGTR_IncreaseRTCMaxUserFreq "Prbld ki ezt: \"echo %lu > /proc/sys/dev/rtc/max-user-freq\" hozzadni a rendszer indt script-jeidhez!\n"
#define MSGTR_LinuxRTCInitErrorPieOn "Linux RTC inicializlsi hiba az ioctl-ben (rtc_pie_on): %s\n"
#define MSGTR_UsingTimingType "%s idzts hasznlata.\n"
#define MSGTR_NoIdleAndGui "Az -idle opci nem hasznlhat a GMPlayerrel.\n"
#define MSGTR_MenuInitialized "Men inicializlva: %s\n"
#define MSGTR_MenuInitFailed "Men inicializls nem sikerlt.\n"
#define MSGTR_Getch2InitializedTwice "FIGYELEM: getch2_init ktszer lett meghvva!\n"
#define MSGTR_DumpstreamFdUnavailable "Ezt a folyamot nem lehet dump-olni - a fjller nem elrhet.\n"
#define MSGTR_FallingBackOnPlaylist "Visszalps a(z) %s lejtszsi lista rtelmezse kzben...\n"
#define MSGTR_CantOpenLibmenuFilterWithThisRootMenu "A libmenu video szrt nem sikerlt a(z) %s fmenvel megnyitni.\n"
#define MSGTR_AudioFilterChainPreinitError "Hiba az audio szr lnc el-inicializlsban!\n"
#define MSGTR_LinuxRTCReadError "Linux RTC olvassi hiba: %s\n"
#define MSGTR_SoftsleepUnderflow "Figyelem! Softsleep alulcsorduls!\n"
#define MSGTR_DvdnavNullEvent "DVDNAV esemny NULL (NINCS)?!\n"
#define MSGTR_DvdnavHighlightEventBroken "DVDNAV esemny: Kiemels esemny hibs\n"
#define MSGTR_DvdnavEvent "DVDNAV esemny: %s\n"
#define MSGTR_DvdnavHighlightHide "DVDNAV esemny: Kiemels elrejtse\n"
#define MSGTR_DvdnavStillFrame "######################################## DVDNAV esemny: Still Frame: %d mp\n"
#define MSGTR_DvdnavNavStop "DVDNAV esemny: Nav Stop\n"
#define MSGTR_DvdnavNavNOP "DVDNAV esemny: Nav NOP\n"
#define MSGTR_DvdnavNavSpuStreamChangeVerbose "DVDNAV esemny: Nav SPU folyam vlts: fizikai: %d/%d/%d logikai: %d\n"
#define MSGTR_DvdnavNavSpuStreamChange "DVDNAV esemny: Nav SPU folyam vlts: fizikai: %d logikai: %d\n"
#define MSGTR_DvdnavNavAudioStreamChange "DVDNAV esemny: Nav Audio folyam vlts: fizikai: %d logikai: %d\n"
#define MSGTR_DvdnavNavVTSChange "DVDNAV esemny: Nav VTS vlts\n"
#define MSGTR_DvdnavNavCellChange "DVDNAV esemny: Nav cella vlts\n"
#define MSGTR_DvdnavNavSpuClutChange "DVDNAV esemny: Nav SPU CLUT vlts\n"
#define MSGTR_DvdnavNavSeekDone "DVDNAV esemny: Nav keress ksz\n"
#define MSGTR_MenuCall "Men hvs\n"

#define MSGTR_EdlOutOfMem "Nem lehet elegend memrit foglalni az EDL adatoknak.\n"
#define MSGTR_EdlRecordsNo "%d EDL akcik olvassa.\n"
#define MSGTR_EdlQueueEmpty "Nincs olyan EDL akci, amivel foglalkozni kellene.\n"
#define MSGTR_EdlCantOpenForWrite "Az EDL fjlba [%s] nem lehet rni.\n"
#define MSGTR_EdlCantOpenForRead "Az EDL fjlt [%s] nem lehet olvasni.\n"
#define MSGTR_EdlNOsh_video "Az EDL nem hasznlhat video nlkl, letiltva.\n"
#define MSGTR_EdlNOValidLine "Hibs EDL sor: %s\n"
#define MSGTR_EdlBadlyFormattedLine "Hibs formtum EDL sor [%d], kihagyva.\n"
#define MSGTR_EdlBadLineOverlap "Az utols meglltsi pozci [%f] volt; a kvetkez indulsi "\
"[%f]. A bejegyzseknek idrendben kell lennik, nem tlapolhatak. Kihagyva.\n"
#define MSGTR_EdlBadLineBadStop "A meglltsi idnek a kezdsi id utn kell lennie.\n"

// mplayer.c OSD

#define MSGTR_OSDenabled "bekapcsolva"
#define MSGTR_OSDdisabled "kikapcsolva"
#define MSGTR_OSDChannel "Csatorna: %s"
#define MSGTR_OSDSubDelay "Sub kss: %d ms"
#define MSGTR_OSDSpeed "Sebessg: x %6.2f"
#define MSGTR_OSDosd "OSD: %s"

// property values
#define MSGTR_Enabled "bekapcsolva"
#define MSGTR_EnabledEdl "bekapcsolva (edl)"
#define MSGTR_Disabled "kikapcsolva"
#define MSGTR_HardFrameDrop "ers"
#define MSGTR_Unknown "ismeretlen"
#define MSGTR_Bottom "alul"
#define MSGTR_Center "kzpen"
#define MSGTR_Top "fent"

// osd bar names
#define MSGTR_Volume "Hanger"
#define MSGTR_Panscan "Panscan"
#define MSGTR_Gamma "Gamma"
#define MSGTR_Brightness "Fnyer"
#define MSGTR_Contrast "Kontraszt"
#define MSGTR_Saturation "Teltettsg"
#define MSGTR_Hue "rnyalat"

// property state
#define MSGTR_MuteStatus "Nmt: %s"
#define MSGTR_AVDelayStatus "A-V kss: %d ms"
#define MSGTR_OnTopStatus "Mindig fell: %s"
#define MSGTR_RootwinStatus "Fablak: %s"
#define MSGTR_BorderStatus "Keret: %s"
#define MSGTR_FramedroppingStatus "Kpkocka dobs: %s"
#define MSGTR_VSyncStatus "VSync: %s"
#define MSGTR_SubSelectStatus "Feliratok: %s"
#define MSGTR_SubPosStatus "Felirat helye: %s/100"
#define MSGTR_SubAlignStatus "Felirat illeszts: %s"
#define MSGTR_SubDelayStatus "Felirat kss: %s"
#define MSGTR_SubVisibleStatus "Feliratok: %s"
#define MSGTR_SubForcedOnlyStatus "Csak knyszertett felirat: %s"

// mencoder.c:

#define MSGTR_UsingPass3ControllFile "Pass3 vezrl fjl hasznlata: %s\n"
#define MSGTR_MissingFilename "\nHinyz fjlnv!\n\n"
#define MSGTR_CannotOpenFile_Device "Fjl/eszkz megnyitsa sikertelen.\n"
#define MSGTR_CannotOpenDemuxer "Demuxer meghvsa sikertelen.\n"
#define MSGTR_NoAudioEncoderSelected "\nNem vlasztottl ki audio enkdert (-oac)! Vlassz egyet (lsd -oac help), vagy hasznld a -nosound opcit!\n"
#define MSGTR_NoVideoEncoderSelected "\nNem vlasztottl ki video enkdert (-ovc)! Vlassz egyet (lsd -ovc help)!\n"
#define MSGTR_CannotOpenOutputFile "Nem tudom a kimeneti fjlt (%s) megnyitni.\n"
#define MSGTR_EncoderOpenFailed "Enkder hvsa sikertelen.\n"
#define MSGTR_MencoderWrongFormatAVI "\nFIGYELEM: A KIMENETI FJL FORMTUM _AVI_. Lsd -of help.\n"
#define MSGTR_MencoderWrongFormatMPG "\nFIGYELEM: A KIMENETI FJL FORMTUM _MPEG_. Lsd -of help.\n"
#define MSGTR_MissingOutputFilename "Nincs kimeneti fjl megadva, lsd a -o kapcsolt"
#define MSGTR_ForcingOutputFourcc "Kimeneti fourcc knyszertse: %x [%.4s]\n"
#define MSGTR_ForcingOutputAudiofmtTag "Audi formtum tag knyszertse: 0x%x\n"
#define MSGTR_DuplicateFrames "\n%d darab kpkocka duplzsa!!!\n"
#define MSGTR_SkipFrame "\nkpkocka tugrsa!!!\n"
#define MSGTR_ResolutionDoesntMatch "\nAz j vide fjl felbontsa vagy szntere klnbzik az elztl.\n"
#define MSGTR_FrameCopyFileMismatch "\nAz sszes vide fjlnak azonos fps-sel, felbontssal, s codec-kel kell rendelkeznie az -ovc copy-hoz.\n"
#define MSGTR_AudioCopyFileMismatch "\nAz sszes fjlnak azonos audi codec-kel s formtummal kell rendelkeznie az -oac copy-hoz.\n"
#define MSGTR_NoAudioFileMismatch "\nNem lehet a csak videt tartalmaz fjlokat sszekeverni audi s vide fjlokkal. Prbld a -nosound kapcsolt.\n"
#define MSGTR_NoSpeedWithFrameCopy "FIGYELEM: A -speed nem biztos, hogy jl mkdik az -oac copy-val!\n"\
"A kdolsod hibs lehet!\n"
#define MSGTR_ErrorWritingFile "%s: hiba a fjl rsnl.\n"
#define MSGTR_RecommendedVideoBitrate "Ajnlott video bitrta %s CD-hez: %d\n"
#define MSGTR_VideoStreamResult "\nVideo stream: %8.3f kbit/mp  (%d B/s)  mret: %d byte  %5.3f mp  %d kpkocka\n"
#define MSGTR_AudioStreamResult "\nAudio stream: %8.3f kbit/mp  (%d B/s)  mret: %d byte  %5.3f mp\n"
#define MSGTR_OpenedStream "ksz: formtum: %d  adat: 0x%X - 0x%x\n"
#define MSGTR_VCodecFramecopy "videocodec: framecopy (%dx%d %dbpp fourcc=%x)\n"
#define MSGTR_ACodecFramecopy "audiocodec: framecopy (formtum=%x csati=%d rta=%d bit=%d B/s=%d sample-%ld)\n"
#define MSGTR_CBRPCMAudioSelected "CBR PCM audio kivlasztva\n"
#define MSGTR_MP3AudioSelected "MP3 audio kivlasztva\n"
#define MSGTR_CannotAllocateBytes "%d byte nem foglalhat le\n"
#define MSGTR_SettingAudioDelay "Audi ksleltets belltsa: %5.3fs\n"
#define MSGTR_SettingVideoDelay "Vide ksleltets belltsa: %5.3fs\n"
#define MSGTR_SettingAudioInputGain "Audio input erstse %f\n"
#define MSGTR_LamePresetEquals "\npreset=%s\n\n"
#define MSGTR_LimitingAudioPreload "Audio elretlts korltozva 0.4 mp-re\n"
#define MSGTR_IncreasingAudioDensity "Audio tmrts nvelse 4-re\n"
#define MSGTR_ZeroingAudioPreloadAndMaxPtsCorrection "Audio elretlts 0-ra lltva, max pts javts 0\n"
#define MSGTR_CBRAudioByterate "\n\nCBR audio: %d byte/mp, %d byte/blokk\n"
#define MSGTR_LameVersion "LAME %s (%s) verzi\n\n"
#define MSGTR_InvalidBitrateForLamePreset "Hiba: A megadott bitrta az ezen belltshoz tartoz hatrokon kvl van\n"\
"\n"\
"Ha ezt a mdot hasznlod, \"8\" s \"320\" kztti rtket kell megadnod\n"\
"\n"\
"Tovbbi informcikrt lsd a \"-lameopts preset=help\" kapcsolt!\n"
#define MSGTR_InvalidLamePresetOptions "Hiba: Nem adtl meg rvnyes profilt s/vagy opcikat a preset-tel\n"\
"\n"\
"Az elrhet profilok:\n"\
"\n"\
"   <fast>        alaprtelmezett\n"\
"   <fast>        extrm\n"\
"                 rlt\n"\
"   <cbr> (ABR Md) - Az ABR Mode beptett. Hasznlathoz\n"\
"                      csak adj meg egy bitrtt. Pldul:\n"\
"                      \"preset=185\" aktivlja ezt a\n"\
"                      belltst s 185 lesz az tlagos kbps.\n"\
"\n"\
"    Nhny plda:\n"\
"\n"\
"    \"-lameopts fast:preset=standard  \"\n"\
" or \"-lameopts  cbr:preset=192       \"\n"\
" or \"-lameopts      preset=172       \"\n"\
" or \"-lameopts      preset=extreme   \"\n"\
"\n"\
"Tovbbi informcikrt lsd a \"-lameopts preset=help\" kapcsolt!\n"
#define MSGTR_LamePresetsLongInfo "\n"\
"A preset kapcsolk azrt lettek ltrehozva, hogy a lehet legjobb minsget biztostsk.\n"\
"\n"\
"Legtbbszr elvakult, knyrtelen vjtflek trgyaljk ki s lltgatjk ket,\n"\
"hogy elrjk a cljaikat.\n"\
"\n"\
"Ezen vltoztatsok folyamatosan frisstsre kerlnek, hogy illeszkedjenek a\n"\
"legjabb fejlesztsekhez s az eredmny majdnem a legjobb minsget biztostsa\n"\
"Neked, ami elrhet a LAME-mel.\n"\
"\n"\
"Preset-ek aktivlsa:\n"\
"\n"\
"   VBR (vltoz bitrta) mdokhoz (ltalban a legjobb minsg):\n"\
"\n"\
"     \"preset=standard\" Ez a bellts ajnlott a legtbb felhasznlnak\n"\
"                             a zenk nagy rsznl, s mr ez is megfelelen\n"\
"                             j minsget biztost.\n"\
"\n"\
"     \"preset=extreme\" Ha klnsen j hallsod s hasonlan j felszerelsed\n"\
"                             van, ez a bellts meglehetsen jobb minsget\n"\
"                             fog biztostani mint a \"standard\" md.\n"\
"                             \n"\
"\n"\
"   CBR (lland bitrta) 320kbps (a preset-tel elrhet legjobb minsg):\n"\
"\n"\
"     \"preset=insane\"  Ez a bellts \"gyuval verbre\" eset a legtbb\n"\
"                             embernl s a legtbb esetben, de ha abszolt a\n"\
"                             legjobb minsgre van szksged a fjl mrettl\n"\
"                             fggetlenl, akkor ez kell neked.\n"\
"\n"\
"   ABR (tlagos bitrta) md (kivl minsg az adott bitrthoz de nem VBR):\n"\
"\n"\
"     \"preset=<kbps>\"  Ezen preset hasznlatval legtbbszr j minsget\n"\
"                             kapsz a megadott bitrtval. Az adott bitrttl\n"\
"                             fggen ez a preset meghatrozza az optimlis\n"\
"                             belltsokat.\n"\
"                             Amg ez a megkzelts mkdik, messze nem olyan\n"\
"                             rugalmas, mint a VBR, s legtbbszr nem lesz\n"\
"                             olyan minsg, mint a magas bitrtj VBR-rel.\n"\
"\n"\
"A kvetkez opcik is elrhetek a megfelel profilokhoz:\n"\
"\n"\
"   <fast>        standard\n"\
"   <fast>        extrm\n"\
"                 rlt\n"\
"   <cbr> (ABR md) - Az ABR md beptett. Hasznlathoz egyszeren\n"\
"                     csak add meg a bitrtt. Pldul:\n"\
"                     \"preset=185\" ezt a preset-et aktivlja\n"\
"                     s 185-s tlagos kbps-t hasznl.\n"\
"\n"\
"   \"fast\" - Engedlyezi az j, gyors VBR-t a megfelel profilban.\n"\
"            Htrnya, hogy a sebessg miatt a bitrta gyakran \n"\
"            kicsit nagyobb lesz, mint a norml mdban, a minsg pedig\n"\
"            kicsit rosszabb.\n"\
"   Figyelem: a jelenlegi llapotban a gyors preset-ek tl nagy bitrtt\n"\
"             produklnak a normlis preset-hez kpest.\n"\
"\n"\
"   \"cbr\"  - Ha az ABR mdot hasznlod (lsd feljebb) egy olyan bitrtval\n"\
"            mint a 80, 96, 112, 128, 160, 192, 224, 256, 320, hasznlhatod\n"\
"            a \"cbr\" opcit hogy elrd a CBR mdot a kdolsnl az\n"\
"            alaprtelmezett abr md helyett. Az ABR jobb minsget biztost,\n"\
"            de a CBR hasznosabb lehet olyan esetekben, mint pl. amikor fontos\n"\
"            az MP3 Interneten trtn streamelhetsge.\n"\
"\n"\
"    Pldul:\n"\
"\n"\
"    \"-lameopts fast:preset=standard  \"\n"\
" or \"-lameopts  cbr:preset=192       \"\n"\
" or \"-lameopts      preset=172       \"\n"\
" or \"-lameopts      preset=extreme   \"\n"\
"\n"\
"\n"\
"Pr lnv, ami elrhet az ABR mdban:\n"\
"phone => 16kbps/mono        phon+/lw/mw-eu/sw => 24kbps/mono\n"\
"mw-us => 40kbps/mono        voice => 56kbps/mono\n"\
"fm/radio/tape => 112kbps    hifi => 160kbps\n"\
"cd => 192kbps               studio => 256kbps"
#define MSGTR_LameCantInit "A Lame opcik nem llthatak be, ellenrizd a"\
"bitrtt/mintavteli rtt, nhny nagyon alacsony bitrthoz (<32) alacsonyabb"\
"mintavteli rta kell (pl. -srate 8000)."\
"Ha minden ms sikertelen, prblj ki egy preset-et."
#define MSGTR_ConfigfileError "konfigurcis fjl hibja"
#define MSGTR_ErrorParsingCommandLine "hiba a parancssor rtelmezsekor"
#define MSGTR_VideoStreamRequired "Video stream szksges!\n"
#define MSGTR_ForcingInputFPS "az input fps inkbb %5.2f-knt lesz rtelmezve\n"
#define MSGTR_RawvideoDoesNotSupportAudio "A RAWVIDEO kimeneti fjl formtum nem tmogatja a hangot - audio letiltva\n"
#define MSGTR_DemuxerDoesntSupportNosound "Ez a demuxer mg nem tmogatja a -nosound kapcsolt.\n"
#define MSGTR_MemAllocFailed "Nem sikerlt a memriafoglals\n"
#define MSGTR_NoMatchingFilter "Nem talltam megfelel szrt/ao formtumot!\n"
#define MSGTR_MP3WaveFormatSizeNot30 "sizeof(MPEGLAYER3WAVEFORMAT)==%d!=30, taln hibs C fordt?\n"
#define MSGTR_NoLavcAudioCodecName "Audio LAVC, hinyz codec nv!\n"
#define MSGTR_LavcAudioCodecNotFound "Audio LAVC, nem tallhat kdol a(z) %s codec-hez.\n"
#define MSGTR_CouldntAllocateLavcContext "Audio LAVC, nem tallhat a kontextus!\n"
#define MSGTR_CouldntOpenCodec "A(z) %s codec nem nyithat meg, br=%d\n"
#define MSGTR_CantCopyAudioFormat "A(z) 0x%x audi formtum nem kompatibilis a '-oac copy'-val, krlek prbld meg a '-oac pcm' helyette vagy hasznld a '-fafmttag'-ot a fellbrlshoz.\n"

// cfg-mencoder.h:

#define MSGTR_MEncoderMP3LameHelp "\n\n"\
" vbr=<0-4>     a vltoz bitrtj kdols mdja\n"\
"                0: cbr\n"\
"                1: mt\n"\
"                2: rh(alaprtelmezett)\n"\
"                3: abr\n"\
"                4: mtrh\n"\
"\n"\
" abr           tlagos bitrta\n"\
"\n"\
" cbr           konstans bitrta\n"\
"               Elrja a CBR md kdolst a ksbbi ABR mdokban is.\n"\
"\n"\
" br=<0-1024>   bitrta kBit-ben (csak CBR s ABR)\n"\
"\n"\
" q=<0-9>       minsg (0-legjobb, 9-legrosszabb) (csak VBR-nl)\n"\
"\n"\
" aq=<0-9>      algoritmikus minsg (0-legjobb, 9-legrosszabb/leggyorsabb)\n"\
"\n"\
" ratio=<1-100> tmrts arnya\n"\
"\n"\
" vol=<0-10>    audio bemenet hangereje\n"\
"\n"\
" mode=<0-3>    (alap: automatikus)\n"\
"                0: stereo\n"\
"                1: joint-stereo\n"\
"                2: dualchannel\n"\
"                3: mono\n"\
"\n"\
" padding=<0-2>\n"\
"                0: nincs\n"\
"                1: mind\n"\
"                2: llts\n"\
"\n"\
" fast          valamivel gyorsabb VBR kdols, kicsit rosszabb minsg s\n"\
"               magasabb bitrta.\n"\
"\n"\
" preset=<rtk> A lehet legjobb minsget biztostja.\n"\
"                 medium: VBR  kdols,  kellemes minsg\n"\
"                 (150-180 kbps bitrta tartomny)\n"\
"                 standard:  VBR kdols, j minsg\n"\
"                 (170-210 kbps bitrta tartomny)\n"\
"                 extreme: VBR kdols, nagyon j minsg\n"\
"                 (200-240 kbps bitrta tartomny)\n"\
"                 insane:  CBR  kdols, legjobb minsg\n"\
"                 (320 kbps bitrta)\n"\
"                 <8-320>: ABR kdols tlagban a megadott bitrtval.\n\n"

//codec-cfg.c:
#define MSGTR_DuplicateFourcc "dupla FourCC"
#define MSGTR_TooManyFourccs "tl sok FourCCs/formtum..."
#define MSGTR_ParseError "rtelmezsi hiba"
#define MSGTR_ParseErrorFIDNotNumber "rtelmezsi hiba (a formtum ID nem szm?)"
#define MSGTR_ParseErrorFIDAliasNotNumber "rtelmezsi hiba (a formtum ID lnv nem szm?)"
#define MSGTR_DuplicateFID "dupliklt formtum ID"
#define MSGTR_TooManyOut "tl sok kiesett..."
#define MSGTR_InvalidCodecName "\na codec(%s) nv hibs!\n"
#define MSGTR_CodecLacksFourcc "\na codec(%s) nem FourCC/formtum!\n"
#define MSGTR_CodecLacksDriver "\na codec(%s) nem rendelkezik vezlvel!\n"
#define MSGTR_CodecNeedsDLL "\na codec(%s) 'dll'-t ignyel!\n"
#define MSGTR_CodecNeedsOutfmt "\ncodec(%s) 'outfmt'-t ignyel!\n"
#define MSGTR_CantAllocateComment "Nem tudok memrit foglalni a megjegyzsnek. "
#define MSGTR_GetTokenMaxNotLessThanMAX_NR_TOKEN "get_token(): max >= MAX_MR_TOKEN!"
#define MSGTR_ReadingFile "%s olvassa: "
#define MSGTR_CantOpenFileError "Nem tudom megnyitni '%s'-t: %s\n"
#define MSGTR_CantGetMemoryForLine "Nem tudok memrit foglalni a 'line'-nak: %s\n"
#define MSGTR_CantReallocCodecsp "A '*codecsp' nem foglalhat le jra: %s\n"
#define MSGTR_CodecNameNotUnique "A(z) '%s' codec nv nem egyedi."
#define MSGTR_CantStrdupName "Nem vgezhet el: strdup -> 'name': %s\n"
#define MSGTR_CantStrdupInfo "Nem vgezhet el: strdup -> 'info': %s\n"
#define MSGTR_CantStrdupDriver "Nem vgezhet el: strdup -> 'driver': %s\n"
#define MSGTR_CantStrdupDLL "Nem vgezhet el: strdup -> 'dll': %s"
#define MSGTR_AudioVideoCodecTotals "%d audi & %d vide codec\n"
#define MSGTR_CodecDefinitionIncorrect "A codec nincs megfelelen definilva."
#define MSGTR_OutdatedCodecsConf "Ez a codecs.conf tl rgi s nem kompatibilis az MPlayer ezen kiadsval!"

// divx4_vbr.c:
#define MSGTR_OutOfMemory "elfogyott a memria"
#define MSGTR_OverridingTooLowBitrate "A megadott bitrta tl alacsony ehhez a klipphez.\n"\
"A minimlis lehetsges bitrta ehhez a klipphez %.0f kbps. A felhasznli\n"\
"rtk fellbrlva.\n"

// fifo.c
#define MSGTR_CannotMakePipe "Nem hozhat ltre PIPE!\n"

// m_config.c
#define MSGTR_SaveSlotTooOld "Tl rgi mentsi slotot talltam az %d lvl-bl: %d !!!\n"
#define MSGTR_InvalidCfgfileOption "A(z) %s kapcsol nem hasznlhat konfigurcis fjlban.\n"
#define MSGTR_InvalidCmdlineOption "A(z) %s kapcsol nem hasznlhat parancssorbl.\n"
#define MSGTR_InvalidSuboption "Hiba: '%s' kapcsolnak nincs '%s' alopcija.\n"
#define MSGTR_MissingSuboptionParameter "Hiba: a(z) '%s' '%s' alkapcsoljhoz paramter kell!\n"
#define MSGTR_MissingOptionParameter "Hiba: a(z) '%s' kapcsolhoz kell egy paramter!\n"
#define MSGTR_OptionListHeader "\n Nv                  Tpus           Min        Max      Globl  CL    Cfg\n\n"
#define MSGTR_TotalOptions "\nsszesen: %d kapcsol\n"
#define MSGTR_TooDeepProfileInclusion "FIGYELMEZTETS: Tl mly profil begyazs.\n"
#define MSGTR_NoProfileDefined "Nincs profil megadva.\n"
#define MSGTR_AvailableProfiles "Elrhet profilok:\n"
#define MSGTR_UnknownProfile "Ismeretlen profil: '%s'.\n"
#define MSGTR_Profile "Profil %s: %s\n"

// m_property.c
#define MSGTR_PropertyListHeader "\n Nv                  Tpus           Min        Max\n\n"
#define MSGTR_TotalProperties "\nsszesen: %d tulajdonsg\n"

// open.c, stream.c:
#define MSGTR_CdDevNotfound "A CD-ROM meghajt (%s) nem tallhat!\n"
#define MSGTR_ErrTrackSelect "Hiba a VCD-sv kivlasztsakor!"
#define MSGTR_ReadSTDIN "Olvass a szabvnyos bemenetrl (stdin)...\n"
#define MSGTR_UnableOpenURL "Nem megnyithat az URL: %s\n"
#define MSGTR_ConnToServer "Csatlakozom a szerverhez: %s\n"
#define MSGTR_FileNotFound "A fjl nem tallhat: '%s'\n"

#define MSGTR_SMBInitError "Samba kliens knyvtr nem inicializlhat: %d\n"
#define MSGTR_SMBFileNotFound "Nem nyithat meg a hlzatrl: '%s'\n"
#define MSGTR_SMBNotCompiled "Nincs befordtva az MPlayerbe az SMB tmogats\n"

#define MSGTR_CantOpenDVD "Nem tudom megnyitni a DVD eszkzt: %s\n"
#define MSGTR_NoDVDSupport "Az MPlayer DVD tmogats nlkl lett lefordtva, kilps\n"
#define MSGTR_DVDwait "A lemez struktrjnak olvassa, krlek vrj...\n"
#define MSGTR_DVDnumTitles "%d sv van a DVD-n.\n"
#define MSGTR_DVDinvalidTitle "Helytelen DVD sv: %d\n"
#define MSGTR_DVDnumChapters "Az adott DVD svban %d fejezet van.\n"
#define MSGTR_DVDinvalidChapter "Helytelen DVD fejezet: %d\n"
#define MSGTR_DVDinvalidChapterRange "Helytelen fejezet tartomny specifikci: %s\n"
#define MSGTR_DVDinvalidLastChapter "Helytelen DVD utols fejezet szm: %d\n"
#define MSGTR_DVDnumAngles "%d darab kameralls van ezen a DVD svon.\n"
#define MSGTR_DVDinvalidAngle "Helytelen DVD kameralls: %d\n"
#define MSGTR_DVDnoIFO "Nem tudom a(z) %d. DVD svhoz megnyitni az IFO fjlt.\n"
#define MSGTR_DVDnoVMG "A VMG inft nem lehet megnyitni!\n"
#define MSGTR_DVDnoVOBs "Nem tudom megnyitni a VOBS svokat (VTS_%02d_1.VOB).\n"
#define MSGTR_DVDnoMatchingAudio "Nem tallhat megfelel nyelv DVD audi!\n"
#define MSGTR_DVDaudioChannel "Kivlasztott DVD audi csatorna: %d nyelv: %c%c\n"
#define MSGTR_DVDnoMatchingSubtitle "Nincs megfelel nyelv DVD felirat fjl!\n"
#define MSGTR_DVDsubtitleChannel "Kivlasztott DVD felirat csatorna: %d nyelv: %c%c\n"
#define MSGTR_DVDopenOk "DVD sikeresen megnyitva!\n"

// muxer.c, muxer_*.c:
#define MSGTR_TooManyStreams "Tl sok stream!"
#define MSGTR_RawMuxerOnlyOneStream "A rawaudio muxer csak egy audi folyamot tmogat!\n"
#define MSGTR_IgnoringVideoStream "Vide folyam figyelmen kvl hagyva!\n"
#define MSGTR_UnknownStreamType "Figyelem! Ismeretlen folyam tpus: %d\n"
#define MSGTR_WarningLenIsntDivisible "Figyelem! A len nem oszthat a samplesize-zal!\n"
#define MSGTR_MuxbufMallocErr "Muxer keret buffernek nem sikerlt memrit foglalni!\n"
#define MSGTR_MuxbufReallocErr "Muxer keret buffernek nem sikerlt memrit jrafoglalni!\n"
#define MSGTR_MuxbufSending "Muxer keret bufferbl %d keret tkldve a muxer-nek.\n"
#define MSGTR_WritingHeader "Fejlc rsa...\n"
#define MSGTR_WritingTrailer "Index rsa...\n"

// demuxer.c, demux_*.c:
#define MSGTR_AudioStreamRedefined "Vigyzat! Tbbszrsen definilt Audio-folyam: %d (Hibs fjl?)\n"
#define MSGTR_VideoStreamRedefined "Vigyzat! Tbbszrsen definilt Video-folyam: %d (Hibs fjl?)\n"
#define MSGTR_TooManyAudioInBuffer "\nDEMUXER: Tl sok (%d db, %d bjt) audio-csomag a pufferben!\n"
#define MSGTR_TooManyVideoInBuffer "\nDEMUXER: Tl sok (%d db, %d bjt) video-csomag a pufferben!\n"
#define MSGTR_MaybeNI "Taln ez egy nem sszefslt (interleaved) fjl vagy a codec nem mkdik jl?\n" \
		      "AVI fjloknl prbld meg a non-interleaved md knyszertst a -ni opcival.\n"
#define MSGTR_SwitchToNi "\nRosszul sszefslt (interleaved) fjl, tvlts -ni mdba!\n"
#define MSGTR_Detected_XXX_FileFormat "Ez egy %s formtum fjl!\n"
#define MSGTR_DetectedAudiofile "Audio fjl detektlva!\n"
#define MSGTR_NotSystemStream "Nem MPEG System Stream formtum... (taln Transport Stream?)\n"
#define MSGTR_InvalidMPEGES "Hibs MPEG-ES-folyam? Lpj kapcsolatba a ksztkkel, lehet, hogy hiba!\n"
#define MSGTR_FormatNotRecognized "========= Sajnos ez a fjlformtum ismeretlen vagy nem tmogatott ===========\n"\
				  "= Ha ez egy AVI, ASF vagy MPEG fjl, lpj kapcsolatba a ksztkkel (hiba)! =\n"
#define MSGTR_MissingVideoStream "Nincs kpfolyam!\n"
#define MSGTR_MissingAudioStream "Nincs hangfolyam... -> hang nlkl\n"
#define MSGTR_MissingVideoStreamBug "Nincs kpfolyam?! rj a szerznek, lehet hogy hiba :(\n"

#define MSGTR_DoesntContainSelectedStream "demux: a fjl nem tartalmazza a krt hang vagy kp folyamot\n"

#define MSGTR_NI_Forced "Knyszertve"
#define MSGTR_NI_Detected "Detektlva"
#define MSGTR_NI_Message "%s NON-INTERLEAVED AVI formtum!\n"

#define MSGTR_UsingNINI "NON-INTERLEAVED hibs AVI formtum hasznlata!\n"
#define MSGTR_CouldntDetFNo "Nem tudom meghatrozni a kpkockk szmt (abszolut tekershez)   \n"
#define MSGTR_CantSeekRawAVI "Nem tudok nyers .AVI-kban tekerni! (index kell, prbld az -idx kapcsolval!)\n"
#define MSGTR_CantSeekFile "Nem tudok ebben a fjlban tekerni!\n"

#define MSGTR_EncryptedVOB "Titkosttt VOB fjl! Olvasd el a DOCS/HTML/hu/cd-dvd.html fjlt!\n"

#define MSGTR_MOVcomprhdr "MOV: A tmrtett fejlcek tmogatshoz ZLIB kell!\n"
#define MSGTR_MOVvariableFourCC "MOV: Vigyzat: vltoz FOURCC detektlva!?\n"
#define MSGTR_MOVtooManyTrk "MOV: Vigyzat: tl sok sv!"
#define MSGTR_FoundAudioStream "==> Megtallt audio folyam: %d\n"
#define MSGTR_FoundVideoStream "==> Megtallt video folyam: %d\n"
#define MSGTR_DetectedTV "TV detektlva! ;-)\n"
#define MSGTR_ErrorOpeningOGGDemuxer "OGG demuxer meghvsa nem sikerlt\n"
#define MSGTR_ASFSearchingForAudioStream "ASF: Audio folyam keresse (id:%d)\n"
#define MSGTR_CannotOpenAudioStream "Audio folyam megnyitsa sikertelen: %s\n"
#define MSGTR_CannotOpenSubtitlesStream "Felirat folyam megnyitsa sikertelen: %s\n"
#define MSGTR_OpeningAudioDemuxerFailed "Audio demuxer meghvsa sikertelen: %s\n"
#define MSGTR_OpeningSubtitlesDemuxerFailed "Felirat demuxer meghvsa sikertelen: %s\n"
#define MSGTR_TVInputNotSeekable "TV bemenet nem tekerhet! (Meg kne csinlni hogy most vltson csatornt ;)\n"
#define MSGTR_DemuxerInfoAlreadyPresent "%s demuxer info mr jelen van!\n"
#define MSGTR_ClipInfo "Klipp info: \n"

#define MSGTR_LeaveTelecineMode "\ndemux_mpg: 30000/1001fps NTSC formtumot talltam, framerta vlts.\n"
#define MSGTR_EnterTelecineMode "\ndemux_mpg: 24000/1001fps progresszv NTSC formtumot talltam, framerta vlts.\n"

#define MSGTR_CacheFill "\rCache feltlts: %5.2f%% (%"PRId64" bytes)   "
#define MSGTR_NoBindFound "Nincs semmi sem sszerendelve a(z) '%s' gombbal"
#define MSGTR_FailedToOpen "Nem lehet megnyitni: %s\n"

// dec_video.c & dec_audio.c:
#define MSGTR_CantOpenCodec "Nem tudom megnyitni a kodeket.\n"
#define MSGTR_CantCloseCodec "Nem tudom lezrni a kodeket.\n"

#define MSGTR_MissingDLLcodec "HIBA: Nem tudom megnyitni a krt DirectShow kodeket: %s\n"
#define MSGTR_ACMiniterror "Nem tudom betlteni/inicializlni a Win32/ACM kodeket (hinyz DLL fjl?)\n"
#define MSGTR_MissingLAVCcodec "Nem tallom a(z) '%s' nev kodeket a libavcodec-ben...\n"

#define MSGTR_MpegNoSequHdr "MPEG: VGZETES: vge lett a fjlnak mikzben a szekvencia fejlcet kerestem\n"
#define MSGTR_CannotReadMpegSequHdr "VGZETES: Nem tudom olvasni a szekvencia fejlcet!\n"
#define MSGTR_CannotReadMpegSequHdrEx "VGZETES: Nem tudom olvasni a szekvencia fejlc kiterjesztst!\n"
#define MSGTR_BadMpegSequHdr "MPEG: Hibs szekvencia fejlc!\n"
#define MSGTR_BadMpegSequHdrEx "MPEG: Hibs szekvencia fejlc kiterjeszts!\n"

#define MSGTR_ShMemAllocFail "Nem tudok megosztott memrit lefoglalni\n"
#define MSGTR_CantAllocAudioBuf "Nem tudok kimeneti hangbuffer lefoglalni\n"

#define MSGTR_UnknownAudio "Ismeretlen/hinyz hangformtum, hang kikapcsolva\n"

#define MSGTR_UsingExternalPP "[PP] Kls minsgjavt szr hasznlata, max minsg = %d\n"
#define MSGTR_UsingCodecPP "[PP] Codecbeli minsgjavts hasznlata, max minsg = %d\n"
#define MSGTR_VideoAttributeNotSupportedByVO_VD "'%s' video tulajdonsg nem tmogatott a kivlasztott vo & vd meghajtk ltal!\n"
#define MSGTR_VideoCodecFamilyNotAvailableStr "A krt [%s] video codec csald (vfm=%s) nem kivlaszthat (fordtsnl kapcsold be!)\n"
#define MSGTR_AudioCodecFamilyNotAvailableStr "A krt [%s] audio codec csald (afm=%s) nem kivlaszthat (fordtsnl kapcsold be!)\n"
#define MSGTR_OpeningVideoDecoder "Video dekder meghvsa: [%s] %s\n"
#define MSGTR_SelectedVideoCodec "Kivlasztott vide codec: [%s] vfm: %s (%s)\n"
#define MSGTR_OpeningAudioDecoder "Audio dekder meghvsa: [%s] %s\n"
#define MSGTR_SelectedAudioCodec "Kivlasztott audi codec: [%s] afm: %s (%s)\n"
#define MSGTR_BuildingAudioFilterChain "Audi szr lnc felptse %dHz/%dch/%s -> %dHz/%dch/%s formtumhoz...\n"
#define MSGTR_UninitVideoStr "uninit video: %s\n"
#define MSGTR_UninitAudioStr "uninit audio: %s\n"
#define MSGTR_VDecoderInitFailed "VDecoder init nem sikerlt :(\n"
#define MSGTR_ADecoderInitFailed "ADecoder init nem sikerlt :(\n"
#define MSGTR_ADecoderPreinitFailed "ADecoder preinit nem sikerlt :(\n"
#define MSGTR_AllocatingBytesForInputBuffer "dec_audio: %d byte alloklsa bemeneti buffernek.\n"
#define MSGTR_AllocatingBytesForOutputBuffer "dec_audio: %d + %d = %d byte alloklsa bemeneti buffernek.\n"

// LIRC:
#define MSGTR_SettingUpLIRC "LIRC tmogats indtsa...\n"
#define MSGTR_LIRCdisabled "Nem fogod tudni hasznlni a tvirnytt.\n"
#define MSGTR_LIRCopenfailed "Nem tudtam megnyitni a lirc tmogatst!\n"
#define MSGTR_LIRCcfgerr "Nem tudom olvasni a LIRC konfigurcis fjlt: %s \n"

// vf.c
#define MSGTR_CouldNotFindVideoFilter "Nem tallhat a kvetkez video szr: '%s'.\n"
#define MSGTR_CouldNotOpenVideoFilter "A kvetkez video szr megnyitsa nem sikerlt: '%s'.\n"
#define MSGTR_OpeningVideoFilter "Video szr megnyitsa: "
#define MSGTR_CannotFindColorspace "Nem tallhat kzs colorspace, mg a 'scale' filterrel sem :(\n"

// vd.c
#define MSGTR_CodecDidNotSet "VDec: a codec nem lltotta be az sh->disp_w s az sh_disp_h izket, megprblom workaroundolni!\n"
#define MSGTR_VoConfigRequest "VDec: vo config krs - %d x %d (preferlt szntr: %s)\n"
#define MSGTR_CouldNotFindColorspace "Nem tallok egyez colorspace-t - jra prblom a -vf scale filterrel...\n"
#define MSGTR_MovieAspectIsSet "A film aspect rtke %.2f:1 - aspect arny javtsa.\n"
#define MSGTR_MovieAspectUndefined "A film aspect rtke nem definilt - nincs arnyjavts.\n"

// vd_dshow.c, vd_dmo.c
#define MSGTR_DownloadCodecPackage "Frisstened/installlnod kell a binris codec csomagot.\nItt megtallod: http://www.mplayerhq.hu/dload.html\n"
#define MSGTR_DShowInitOK "INFO: Win32/DShow video codec inicializlsa OK.\n"
#define MSGTR_DMOInitOK "INFO: Win32/DMO video codec init OK.\n"

// x11_common.c
#define MSGTR_EwmhFullscreenStateFailed "\nX11: Nem lehet EWMH fullscreen esemnyt kldeni!\n"
#define MSGTR_CouldNotFindXScreenSaver "xscreensaver_disable: Nem tallhat az XScreenSaver ablak.\n"
#define MSGTR_SelectedVideoMode "XF86VM: %dx%d kivlasztott vide md a(z) %dx%d kpmrethez.\n"

#define MSGTR_InsertingAfVolume "[Mixer] Nincs hardveres kevers, hanger szr hasznlata.\n"
#define MSGTR_NoVolume "[Mixer] Hanger llts nem lehetsges.\n"

// ====================== GUI messages/buttons ========================

#ifdef HAVE_NEW_GUI

// --- labels ---
#define MSGTR_About "Az MPlayerrl"
#define MSGTR_FileSelect "Fjl kivlasztsa..."
#define MSGTR_SubtitleSelect "Felirat kivlasztsa..."
#define MSGTR_OtherSelect "Fjl kivlasztsa..."
#define MSGTR_AudioFileSelect "Kls audio csatorna vlasztsa..."
#define MSGTR_FontSelect "Bettpus kivlasztsa..."
// Megjegyzs: Ha megvltoztatod az MSGTR_PlayList-et, nzd meg, hogy megfelel-e az MSGTR_MENU_PlayList-nek is!
#define MSGTR_PlayList "Lejtszsi lista"
#define MSGTR_Equalizer "Equalizer"
#define MSGTR_SkinBrowser "Skin bngsz"
#define MSGTR_Network "Hlzati stream-els..."
// Megjegyzs: Ha megvltoztatod az MSGTR_Preferences-t, nzd meg, hogy megfelel-e az MSGTR_MENU_Preferences-nek is!
#define MSGTR_Preferences "Belltsok"
#define MSGTR_AudioPreferences "Audio vezrl belltsa"
#define MSGTR_NoMediaOpened "nincs megnyitva semmi"
#define MSGTR_VCDTrack "%d. VCD track"
#define MSGTR_NoChapter "nincs megnyitott fejezet"
#define MSGTR_Chapter "%d. fejezet"
#define MSGTR_NoFileLoaded "nincs fjl betltve"

// --- buttons ---
#define MSGTR_Ok "Ok"
#define MSGTR_Cancel "Mgse"
#define MSGTR_Add "Hozzad"
#define MSGTR_Remove "Kivesz"
#define MSGTR_Clear "Trls"
#define MSGTR_Config "Bellts"
#define MSGTR_ConfigDriver "Vezrl belltsa"
#define MSGTR_Browse "Tallzs"

// --- error messages ---
#define MSGTR_NEMDB "Nincs elg memria a buffer kirajzolshoz."
#define MSGTR_NEMFMR "Nincs elg memria a men renderelshez."
#define MSGTR_IDFGCVD "Nem talaltam GUI kompatibilis video meghajtt."
#define MSGTR_NEEDLAVCFAME "Nem MPEG fjl lejtszsa nem lehetsges a DXR3/H+ hardverrel jrakdols nlkl.\nKapcsold be a lavc vagy fame opcit a DXR3/H+ konfigurcis panelen."
#define MSGTR_UNKNOWNWINDOWTYPE "Ismeretlen ablak tpust talltam ..."

// --- skin loader error messages
#define MSGTR_SKIN_ERRORMESSAGE "[skin] hiba a skin konfigurcis fjljnak %d. sorban: %s"
#define MSGTR_SKIN_WARNING1 "[skin] figyelmeztets a skin konfigurcis fjljnak %d. sorban: widget (%S) megvan, de nincs eltte \"section\""
#define MSGTR_SKIN_WARNING2 "[skin] figyelmeztets a skin konfigurcis fjljnak %d. sorban: widget (%S) megvan, de nincs eltte \"subsection\""
#define MSGTR_SKIN_WARNING3 "[skin] figyelmeztets a skin konfigurcis fjljnak %d. sorban: ez az elem nem hasznlhat ebben az alrszben (%s)"
#define MSGTR_SKIN_SkinFileNotFound "[skin] a fjl ( %s ) nem tallhat.\n"
#define MSGTR_SKIN_SkinFileNotReadable "[skin] fjl ( %s ) nem olvashat.\n"
#define MSGTR_SKIN_BITMAP_16bit  "16 vagy kevesebb bites bitmap nem tmogatott (%s).\n"
#define MSGTR_SKIN_BITMAP_FileNotFound  "fjl nem tallhat (%s)\n"
#define MSGTR_SKIN_BITMAP_BMPReadError "BMP olvassi hiba (%s)\n"
#define MSGTR_SKIN_BITMAP_TGAReadError "TGA olvassi hiba (%s)\n"
#define MSGTR_SKIN_BITMAP_PNGReadError "PNG olvassi hiba (%s)\n"
#define MSGTR_SKIN_BITMAP_RLENotSupported "RLE tmrtett TGA-k nincsenek tmogatva (%s)\n"
#define MSGTR_SKIN_BITMAP_UnknownFileType "ismeretlen tipus fjl (%s)\n"
#define MSGTR_SKIN_BITMAP_ConvertError "hiba a 24-rl 32 bitre konvertls kzben (%s)\n"
#define MSGTR_SKIN_BITMAP_UnknownMessage "ismeretlen zenet: %s\n"
#define MSGTR_SKIN_FONT_NotEnoughtMemory "nincs elg memria\n"
#define MSGTR_SKIN_FONT_TooManyFontsDeclared "Tl sok bettipus van deklarlva.\n"
#define MSGTR_SKIN_FONT_FontFileNotFound "Nem tallom a bettipus fjlt.\n"
#define MSGTR_SKIN_FONT_FontImageNotFound "Nem tallom a bettipus kpfjlt.\n"
#define MSGTR_SKIN_FONT_NonExistentFontID "nemltez bettipus azonost (%s)\n"
#define MSGTR_SKIN_UnknownParameter "ismeretlen paramter (%s)\n"
#define MSGTR_SKIN_SKINCFG_SkinNotFound "Skin nem tallhat (%s).\n"
#define MSGTR_SKIN_SKINCFG_SelectedSkinNotFound "A kivlasztott skin ( %s ) nem tallhat, a 'default'-ot prblom meg...\n"
#define MSGTR_SKIN_SKINCFG_SkinCfgReadError "Skin konfigurcis fjl olvassi hiba (%s).\n"
#define MSGTR_SKIN_LABEL "Skin-ek:"

// --- gtk menus
#define MSGTR_MENU_AboutMPlayer "Az MPlayer-rl"
#define MSGTR_MENU_Open "Megnyits..."
#define MSGTR_MENU_PlayFile "Fjl lejtszs..."
#define MSGTR_MENU_PlayVCD "VCD lejtszs..."  
#define MSGTR_MENU_PlayDVD "DVD lejtszs..."  
#define MSGTR_MENU_PlayURL "URL lejtszs..."  
#define MSGTR_MENU_LoadSubtitle "Felirat betltse..."
#define MSGTR_MENU_DropSubtitle "Felirat eldobsa..."
#define MSGTR_MENU_LoadExternAudioFile "Kls hang betltse..."
#define MSGTR_MENU_Playing "Lejtszs"
#define MSGTR_MENU_Play "Lejtszs"
#define MSGTR_MENU_Pause "Pillanatllj"
#define MSGTR_MENU_Stop "llj"  
#define MSGTR_MENU_NextStream "Kvetkez fjl"
#define MSGTR_MENU_PrevStream "Elz fjl"
#define MSGTR_MENU_Size "Mret"
#define MSGTR_MENU_HalfSize   "Fl mret"
#define MSGTR_MENU_NormalSize "Norml mret"
#define MSGTR_MENU_DoubleSize "Dupla mret"
#define MSGTR_MENU_FullScreen "Teljeskperny" 
#define MSGTR_MENU_DVD "DVD"
#define MSGTR_MENU_VCD "VCD"
#define MSGTR_MENU_PlayDisc "Lemez megnyitsa..."
#define MSGTR_MENU_ShowDVDMenu "DVD men"
#define MSGTR_MENU_Titles "Svok"
#define MSGTR_MENU_Title "%2d. sv"
#define MSGTR_MENU_None "(nincs)"
#define MSGTR_MENU_Chapters "Fejezetek"
#define MSGTR_MENU_Chapter "%2d. fejezet"
#define MSGTR_MENU_AudioLanguages "Szinkron nyelvei"
#define MSGTR_MENU_SubtitleLanguages "Feliratok nyelvei"
#define MSGTR_MENU_PlayList MSGTR_PlayList
#define MSGTR_MENU_SkinBrowser "Skin bngsz"
#define MSGTR_MENU_Preferences MSGTR_Preferences
#define MSGTR_MENU_Exit "Kilps..."
#define MSGTR_MENU_Mute "Nma"
#define MSGTR_MENU_Original "Eredeti"
#define MSGTR_MENU_AspectRatio "Kparny"
#define MSGTR_MENU_AudioTrack "Audio track"
#define MSGTR_MENU_Track "%d. sv"
#define MSGTR_MENU_VideoTrack "Video track"

// --- equalizer
// Megjegyzs: Ha megvltoztatod az MSGTR_EQU_Audio-t, nzd meg, hogy megfelel-e az MSGTR_PREFERENCES_Audio-nak is!
#define MSGTR_EQU_Audio "Audi"
// Megjegyzs: Ha megvltoztatod az MSGTR_EQU_Video-t, nzd meg, hogy megfelel-e az MSGTR_PREFERENCES_Video-nak is!
#define MSGTR_EQU_Video "Vide"
#define MSGTR_EQU_Contrast "Kontraszt: "
#define MSGTR_EQU_Brightness "Fnyer: "
#define MSGTR_EQU_Hue "Szinrnyalat: "
#define MSGTR_EQU_Saturation "Teltettsg: "
#define MSGTR_EQU_Front_Left "Bal Els"
#define MSGTR_EQU_Front_Right "Jobb Els"
#define MSGTR_EQU_Back_Left "Bal Hts"
#define MSGTR_EQU_Back_Right "Jobb Hts"
#define MSGTR_EQU_Center "Kzps"
#define MSGTR_EQU_Bass "Basszus"
#define MSGTR_EQU_All "Mindegyik"
#define MSGTR_EQU_Channel1 "1. Csatorna:"
#define MSGTR_EQU_Channel2 "2. Csatorna:"
#define MSGTR_EQU_Channel3 "3. Csatorna:"
#define MSGTR_EQU_Channel4 "4. Csatorna:"
#define MSGTR_EQU_Channel5 "5. Csatorna:"
#define MSGTR_EQU_Channel6 "6. Csatorna:"

// --- playlist
#define MSGTR_PLAYLIST_Path "tvonal"
#define MSGTR_PLAYLIST_Selected "Kivlasztott fjlok"
#define MSGTR_PLAYLIST_Files "Fjlok"
#define MSGTR_PLAYLIST_DirectoryTree "Knyvtr lista"

// --- preferences
#define MSGTR_PREFERENCES_Audio MSGTR_EQU_Audio
#define MSGTR_PREFERENCES_Video MSGTR_EQU_Video
#define MSGTR_PREFERENCES_SubtitleOSD "Felirat & OSD"
#define MSGTR_PREFERENCES_Codecs "Kodekek s demuxerek"
// Megjegyzs: Ha megvltoztatod az MSGTR_PREFERENCES_Misc-et, nzd meg, hogy megfelel-e az MSGTR_PREFERENCES_FRAME_Misc-nek is!
#define MSGTR_PREFERENCES_Misc "Egyb"

#define MSGTR_PREFERENCES_None "Egyik sem"
#define MSGTR_PREFERENCES_DriverDefault "alaprtelmezett vezrl"
#define MSGTR_PREFERENCES_AvailableDrivers "Driverek:"
#define MSGTR_PREFERENCES_DoNotPlaySound "Hang nlkl"
#define MSGTR_PREFERENCES_NormalizeSound "Hang normalizlsa"
#define MSGTR_PREFERENCES_EnEqualizer "Audio equalizer"
#define MSGTR_PREFERENCES_SoftwareMixer "Szoftveres kevers"
#define MSGTR_PREFERENCES_ExtraStereo "Extra stereo"
#define MSGTR_PREFERENCES_Coefficient "Egytthat:"
#define MSGTR_PREFERENCES_AudioDelay "Hang ksleltets"
#define MSGTR_PREFERENCES_DoubleBuffer "Dupla bufferels"
#define MSGTR_PREFERENCES_DirectRender "Direct rendering"
#define MSGTR_PREFERENCES_FrameDrop "Kp eldobs"
#define MSGTR_PREFERENCES_HFrameDrop "Erszakos kp eldob"
#define MSGTR_PREFERENCES_Flip "Kp fejjel lefel"
#define MSGTR_PREFERENCES_Panscan "Panscan: "
#define MSGTR_PREFERENCES_OSDTimer "ra es indiktorok"
#define MSGTR_PREFERENCES_OSDProgress "Csak a szzalk jelzk"
#define MSGTR_PREFERENCES_OSDTimerPercentageTotalTime "ra, szzalk s a teljes id"
#define MSGTR_PREFERENCES_Subtitle "Felirat:"
#define MSGTR_PREFERENCES_SUB_Delay "Ksleltets: "
#define MSGTR_PREFERENCES_SUB_FPS "FPS:"
#define MSGTR_PREFERENCES_SUB_POS "Pozcija: "
#define MSGTR_PREFERENCES_SUB_AutoLoad "Felirat automatikus betltsnek tiltsa"
#define MSGTR_PREFERENCES_SUB_Unicode "Unicode felirat"
#define MSGTR_PREFERENCES_SUB_MPSUB "A film feliratnak konvertlsa MPlayer felirat formtumba"
#define MSGTR_PREFERENCES_SUB_SRT "A film feliratnak konvertlsa SubViewer (SRT) formtumba"
#define MSGTR_PREFERENCES_SUB_Overlap "Felirat tlapols"
#define MSGTR_PREFERENCES_Font "Betk:"
#define MSGTR_PREFERENCES_FontFactor "Bet egytthat:"
#define MSGTR_PREFERENCES_PostProcess "Kpjavts"
#define MSGTR_PREFERENCES_AutoQuality "Autmatikus minsg llts: "
#define MSGTR_PREFERENCES_NI "non-interleaved  AVI  felttelezse (hibs AVI-knl segthet"
#define MSGTR_PREFERENCES_IDX "Az AVI indexnek jraptse, ha szksges"
#define MSGTR_PREFERENCES_VideoCodecFamily "Video kodek csald:"
#define MSGTR_PREFERENCES_AudioCodecFamily "Audio kodek csald:"
#define MSGTR_PREFERENCES_FRAME_OSD_Level "OSD szint"
#define MSGTR_PREFERENCES_FRAME_Subtitle "Felirat"
#define MSGTR_PREFERENCES_FRAME_Font "Bet"
#define MSGTR_PREFERENCES_FRAME_PostProcess "Kpjavts"
#define MSGTR_PREFERENCES_FRAME_CodecDemuxer "Codec & demuxer"
#define MSGTR_PREFERENCES_FRAME_Cache "Gyorsttr"
#define MSGTR_PREFERENCES_FRAME_Misc MSGTR_PREFERENCES_Misc
#define MSGTR_PREFERENCES_Audio_Device "Eszkz:"
#define MSGTR_PREFERENCES_Audio_Mixer "Mixer:"
#define MSGTR_PREFERENCES_Audio_MixerChannel "Mixer csatorna:"
#define MSGTR_PREFERENCES_Message "Krlek emlkezz, nhny opci ignyli a lejtszs jraindtst."
#define MSGTR_PREFERENCES_DXR3_VENC "Video kdol:"
#define MSGTR_PREFERENCES_DXR3_LAVC "LAVC hasznlata (FFmpeg)"
#define MSGTR_PREFERENCES_DXR3_FAME "FAME hasznlata"
#define MSGTR_PREFERENCES_FontEncoding1 "Unicode"
#define MSGTR_PREFERENCES_FontEncoding2 "Nyugat-Eurpai karakterkszlet (ISO-8859-1)"
#define MSGTR_PREFERENCES_FontEncoding3 "Nyugat-Eurpai karakterkszlet eurval (ISO-8859-15)"
#define MSGTR_PREFERENCES_FontEncoding4 "Szlv s kzp-eurpai karakterkszlet (ISO-8859-2)"
#define MSGTR_PREFERENCES_FontEncoding5 "Eszperant, gall, mltai s trk karakterkszlet (ISO-8859-3)"
#define MSGTR_PREFERENCES_FontEncoding6 "Rgi balti karakterkszlet (ISO-8859-4)"
#define MSGTR_PREFERENCES_FontEncoding7 "Cirill karakterkszlet (ISO-8859-5)"
#define MSGTR_PREFERENCES_FontEncoding8 "Arab karakterkszlet (ISO-8859-6)"
#define MSGTR_PREFERENCES_FontEncoding9 "Modern grg karakterkszlet (ISO-8859-7)"
#define MSGTR_PREFERENCES_FontEncoding10 "Trk karakterkszlet (ISO-8859-9)"
#define MSGTR_PREFERENCES_FontEncoding11 "Baltik karakterkszlet (ISO-8859-13)"
#define MSGTR_PREFERENCES_FontEncoding12 "Kelta karakterkszlet (ISO-8859-14)"
#define MSGTR_PREFERENCES_FontEncoding13 "Hber karakterkszlet (ISO-8859-8)"
#define MSGTR_PREFERENCES_FontEncoding14 "Orosz karakterkszlet (KOI8-R)"
#define MSGTR_PREFERENCES_FontEncoding15 "Ukrn, Belorusz karakterkszlet (KOI8-U/UR)"
#define MSGTR_PREFERENCES_FontEncoding16 "Egyszer knai karakterkszlet (CP936)"
#define MSGTR_PREFERENCES_FontEncoding17 "Tradicionlis knai karakterkszlet (BIG5)"
#define MSGTR_PREFERENCES_FontEncoding18 "Japn karakterkszlet (SHIFT-JIS)"
#define MSGTR_PREFERENCES_FontEncoding19 "Koreai karakterkszlet (CP949)"
#define MSGTR_PREFERENCES_FontEncoding20 "Thai karakterkszlet (CP874)"
#define MSGTR_PREFERENCES_FontEncoding21 "Cirill karakterkszlet (Windows) (CP1251)"
#define MSGTR_PREFERENCES_FontEncoding22 "Szlv s kzp-eurpai karakterkszlet (Windows) (CP1250)"
#define MSGTR_PREFERENCES_FontNoAutoScale "Nincs automata karaktermret vlaszts"
#define MSGTR_PREFERENCES_FontPropWidth "Karaktermret film szlessghez val lltsa"
#define MSGTR_PREFERENCES_FontPropHeight "Karaktermret film magassghoz val lltsa"
#define MSGTR_PREFERENCES_FontPropDiagonal "Karaktermret film tljhoz val lltsa"
#define MSGTR_PREFERENCES_FontEncoding "Kdols:"
#define MSGTR_PREFERENCES_FontBlur "Blur:"
#define MSGTR_PREFERENCES_FontOutLine "Krvonal:"
#define MSGTR_PREFERENCES_FontTextScale "Szveg skla:"
#define MSGTR_PREFERENCES_FontOSDScale "OSD skla:"
#define MSGTR_PREFERENCES_Cache "Gyorsttr be/ki"
#define MSGTR_PREFERENCES_CacheSize "Gyorsttr merete:"
#define MSGTR_PREFERENCES_LoadFullscreen "Indts teljes kpernyn"
#define MSGTR_PREFERENCES_SaveWinPos "Ablakok pozcijnak mentse"
#define MSGTR_PREFERENCES_XSCREENSAVER "XScreenSaver lelltsa film lejtszsakor"
#define MSGTR_PREFERENCES_PlayBar "PlayBar engedlyezse"
#define MSGTR_PREFERENCES_AutoSync "AutoSync ki/be"
#define MSGTR_PREFERENCES_AutoSyncValue "rtke:"
#define MSGTR_PREFERENCES_CDROMDevice "CD meghajt:"
#define MSGTR_PREFERENCES_DVDDevice "DVD meghajt:"
#define MSGTR_PREFERENCES_FPS "Film FPS:"
#define MSGTR_PREFERENCES_ShowVideoWindow "Lejtsz ablak megjelentse ha inaktv"
#define MSGTR_PREFERENCES_ArtsBroken "Az jabb aRts verzik inkompatibilisek "\
           "a GTK 1.x-szel s sszeomlasztjk a GMPlayert!"

#define MSGTR_ABOUT_UHU "GUI fejlesztst az UHU Linux tmogatta\n"
#define MSGTR_ABOUT_Contributors "Kd s dokumentci kzremkdi\n"
#define MSGTR_ABOUT_Codecs_libs_contributions "Codec-ek s third party knyvtrak\n"
#define MSGTR_ABOUT_Translations "Fordtsok\n"
#define MSGTR_ABOUT_Skins "Skin-ek\n"

// --- messagebox
#define MSGTR_MSGBOX_LABEL_FatalError "Vgzetes hiba!"
#define MSGTR_MSGBOX_LABEL_Error "Hiba!"
#define MSGTR_MSGBOX_LABEL_Warning "Figyelmeztets!"

// bitmap.c

#define MSGTR_NotEnoughMemoryC32To1 "[c32to1] nincs elg memria a kphez\n"
#define MSGTR_NotEnoughMemoryC1To32 "[c1to32] nincs elg memria a kphez\n"

// cfg.c

#define MSGTR_ConfigFileReadError "[cfg] hiba a konfigurcis fjl olvassakor ...\n"
#define MSGTR_UnableToSaveOption "[cfg] A(z) '%s' opcit nem sikerlt elmenteni.\n"

// interface.c

#define MSGTR_DeletingSubtitles "[GUI] Feliratok trlse.\n"
#define MSGTR_LoadingSubtitles "[GUI] Feliratok betltse: %s\n"
#define MSGTR_AddingVideoFilter "[GUI] Vide szr hozzadsa: %s\n"
#define MSGTR_RemovingVideoFilter "[GUI] Vide szr eltvoltsa: %s\n"

// mw.c

#define MSGTR_NotAFile "gy tnik, hogy ez nem fjl: %s !\n"

// ws.c

#define MSGTR_WS_CouldNotOpenDisplay "[ws] A kperny nem nyithat meg.\n"
#define MSGTR_WS_RemoteDisplay "[ws] Tvoli kperny, XMITSHM kikapcsolva.\n"
#define MSGTR_WS_NoXshm "[ws] Bocs, a rendszered nem tmogatja az X osztott memria kiterjesztst.\n"
#define MSGTR_WS_NoXshape "[ws] Bocs, a rendszered nem tmogatja az XShape kiterjesztst.\n"
#define MSGTR_WS_ColorDepthTooLow "[ws] Bocs, a szn mlysg tl kicsi.\n"
#define MSGTR_WS_TooManyOpenWindows "[ws] Tl sok nyitott ablak van.\n"
#define MSGTR_WS_ShmError "[ws] osztott memria kiterjeszts hibja\n"
#define MSGTR_WS_NotEnoughMemoryDrawBuffer "[ws] Bocs, nincs elg memria a rajz buffernek.\n"
#define MSGTR_WS_DpmsUnavailable "A DPMS nem elrhet?\n"
#define MSGTR_WS_DpmsNotEnabled "A DPMS nem engedlyezhet.\n"

// wsxdnd.c

#define MSGTR_WS_NotAFile "gy tnik, hogy ez nem fjl...\n"
#define MSGTR_WS_DDNothing "D&D: Semmi sem jtt vissza!\n"

#endif

// ======================= VO Video Output drivers ========================

#define MSGTR_VOincompCodec "A kivlasztott video_out eszkz nem kompatibilis ezzel a codec-kel.\n"\
                "Prbld meg hozzadni a scale szrt, pl. -vf spp,scale a -vf spp helyett.\n"
#define MSGTR_VO_GenericError "Hiba trtnt"
#define MSGTR_VO_UnableToAccess "Nem elrhet"
#define MSGTR_VO_ExistsButNoDirectory "mr ltezik, de nem knyvtr."
#define MSGTR_VO_DirExistsButNotWritable "A clknyvtr mr ltezik, de nem rhat."
#define MSGTR_VO_DirExistsAndIsWritable "A clknyvtr mr ltezik s rhat."
#define MSGTR_VO_CantCreateDirectory "Nem tudtam ltrehozni a clknyvtrat."
#define MSGTR_VO_CantCreateFile "A kimeneti fjl nem hozhat ltre."
#define MSGTR_VO_DirectoryCreateSuccess "A clknyvtrat sikeresen ltrehoztam."
#define MSGTR_VO_ParsingSuboptions "Alopcik rtelmezse."
#define MSGTR_VO_SuboptionsParsedOK "Alopcik rtelmezse rendben."
#define MSGTR_VO_ValueOutOfRange "rtk hatron kvl"
#define MSGTR_VO_NoValueSpecified "Nincs rtk megadva."
#define MSGTR_VO_UnknownSuboptions "Ismeretlen alopci(k)"

// vo_aa.c

#define MSGTR_VO_AA_HelpHeader "\n\nEzek az aalib vo_aa alopcii:\n"
#define MSGTR_VO_AA_AdditionalOptions "A vo_aa ltal biztostott opcik:\n" \
"  help        kirja ezt a sgt\n" \
"  osdcolor    osd szn belltsa\n  subcolor    feliratszn belltsa\n" \
"        a szn paramterek:\n           0 : norml\n" \
"           1 : dim\n           2 : flkvr\n           3 : boldfont\n" \
"           4 : fordtott\n           5 : specilis\n\n\n"

// vo_jpeg.c
#define MSGTR_VO_JPEG_ProgressiveJPEG "Progresszv JPEG engedlyezve."
#define MSGTR_VO_JPEG_NoProgressiveJPEG "Progresszv JPEG letiltva."
#define MSGTR_VO_JPEG_BaselineJPEG "Baseline JPEG engedlyezve."
#define MSGTR_VO_JPEG_NoBaselineJPEG "Baseline JPEG letiltva."

// vo_pnm.c
#define MSGTR_VO_PNM_ASCIIMode "ASCII md engedlyezve."
#define MSGTR_VO_PNM_RawMode "Raw md engedlyezve."
#define MSGTR_VO_PNM_PPMType "PPM fjlok rsa."
#define MSGTR_VO_PNM_PGMType "PGM fjlok rsa."
#define MSGTR_VO_PNM_PGMYUVType "PGMYUV fjlok rsa."

// vo_yuv4mpeg.c
#define MSGTR_VO_YUV4MPEG_InterlacedHeightDivisibleBy4 "Az interlaced mdhoz nggyel oszthat kp magassg szksges."
#define MSGTR_VO_YUV4MPEG_InterlacedLineBufAllocFail "Nem sikerlt sor buffert foglalni az interlaced mdhoz."
#define MSGTR_VO_YUV4MPEG_InterlacedInputNotRGB "Input nem RGB, nem lehet sztvlasztani a szneket meznknt!"
#define MSGTR_VO_YUV4MPEG_WidthDivisibleBy2 "A kp szlessgnek kettvel oszthatnak kell lennie."
#define MSGTR_VO_YUV4MPEG_NoMemRGBFrameBuf "Nincs elg memria az RGB framebuffer lefoglalshoz."
#define MSGTR_VO_YUV4MPEG_OutFileOpenError "Nincs elegend memria vagy fjl handle a(z) \"%s\" rshoz!"
#define MSGTR_VO_YUV4MPEG_OutFileWriteError "Hiba a kp kimenetre rsa kzben!"
#define MSGTR_VO_YUV4MPEG_UnknownSubDev "Ismeretlen aleszkz: %s"
#define MSGTR_VO_YUV4MPEG_InterlacedTFFMode "Interlaced kimeneti md hasznlata, top-field elszr."
#define MSGTR_VO_YUV4MPEG_InterlacedBFFMode "Interlaced kimeneti md hasznlata, bottom-field elszr."
#define MSGTR_VO_YUV4MPEG_ProgressiveMode "Progresszv (alaprtelmezett) frame md hasznlata."

// sub.c
#define MSGTR_VO_SUB_Seekbar "Keressv"
#define MSGTR_VO_SUB_Play "Lejtszs"
#define MSGTR_VO_SUB_Pause "Pillanat llj"
#define MSGTR_VO_SUB_Stop "llj"
#define MSGTR_VO_SUB_Rewind "Vissza"
#define MSGTR_VO_SUB_Forward "Elre"
#define MSGTR_VO_SUB_Clock "ra"
#define MSGTR_VO_SUB_Contrast "Kontraszt"
#define MSGTR_VO_SUB_Saturation "Teltettsg"
#define MSGTR_VO_SUB_Volume "Hanger"
#define MSGTR_VO_SUB_Brightness "Fnyer"
#define MSGTR_VO_SUB_Hue "Sznrnyalat"

// vo_xv.c
#define MSGTR_VO_XV_ImagedimTooHigh "A forrs kp mretei tl nagyok: %ux%u (maximum %ux%u)\n"

// Old vo drivers that have been replaced

#define MSGTR_VO_PGM_HasBeenReplaced "A pgm video kimeneti vezrlt lecserlte a -vo pnm:pgmyuv.\n"
#define MSGTR_VO_MD5_HasBeenReplaced "Az md5 video kimeneti vezrlt lecserlte a -vo md5sum.\n"

// ======================= AO Audio Output drivers ========================

// libao2 

// audio_out.c
#define MSGTR_AO_ALSA9_1x_Removed "audio_out: alsa9 s alsa1x modulok trlve lettek, hasznld a -ao alsa kapcsolt helyettk.\n"

// ao_oss.c
#define MSGTR_AO_OSS_CantOpenMixer "[AO OSS] audio_setup: Nem tudom megnyitni a(z) %s kever eszkzt: %s\n"
#define MSGTR_AO_OSS_ChanNotFound "[AO OSS] audio_setup: A hangkrtya keverjnek nincs '%s' csatornja, az alaprtelmezettet hasznlom.\n"
#define MSGTR_AO_OSS_CantOpenDev "[AO OSS] audio_setup: A(z) %s audio eszkzt nem tudom megnyitni: %s\n"
#define MSGTR_AO_OSS_CantMakeFd "[AO OSS] audio_setup: Nem lehet fjl ler blokkolst vgezni: %s\n"
#define MSGTR_AO_OSS_CantSet "[AO OSS] A(z) %s audio eszkz nem llthat be %s kimenetre, %s-t prblok...\n"
#define MSGTR_AO_OSS_CantSetChans "[AO OSS] audio_setup: Nem sikerlt az audio eszkzt %d csatornra lltani.\n"
#define MSGTR_AO_OSS_CantUseGetospace "[AO OSS] audio_setup: a vezrl nem tmogatja a SNDCTL_DSP_GETOSPACE-t :-(\n"
#define MSGTR_AO_OSS_CantUseSelect "[AO OSS]\n   ***  Az audio vezrld NEM tmogatja a select() -et ***\n Fordtsd jra az MPlayer-t az #undef HAVE_AUDIO_SELECT sorral a config.h-ban!\n\n"
#define MSGTR_AO_OSS_CantReopen "[AO OSS]\nVgzetes hiba: *** NEM LEHET JRA MEGNYITNI / BELLTANI AZ AUDIO ESZKZT *** %s\n"
#define MSGTR_AO_OSS_UnknownUnsupportedFormat "[AO OSS] Ismeretlen/Nem tmogatott OSS formtum: %x.\n"

// ao_arts.c
#define MSGTR_AO_ARTS_CantInit "[AO ARTS] %s\n"
#define MSGTR_AO_ARTS_ServerConnect "[AO ARTS] Csatlakoztam a hang szerverhez.\n"
#define MSGTR_AO_ARTS_CantOpenStream "[AO ARTS] Nem lehet megnyitni a folyamot.\n"
#define MSGTR_AO_ARTS_StreamOpen "[AO ARTS] Folyam megnyitva.\n"
#define MSGTR_AO_ARTS_BufferSize "[AO ARTS] buffer mrete: %d\n"

// ao_dxr2.c
#define MSGTR_AO_DXR2_SetVolFailed "[AO DXR2] Hanger belltsa %d-re sikertelen.\n"
#define MSGTR_AO_DXR2_UnsupSamplerate "[AO DXR2] %d Hz nem tmogatott, prbld a resample-t\n"

// ao_esd.c
#define MSGTR_AO_ESD_CantOpenSound "[AO ESD] esd_open_sound sikertelen: %s\n"
#define MSGTR_AO_ESD_LatencyInfo "[AO ESD] latency: [szerver: %0.2fs, net: %0.2fs] (igazts %0.2fs)\n"
#define MSGTR_AO_ESD_CantOpenPBStream "[AO ESD] nem sikerlt megnyitni az ESD playback folyamot: %s\n"

// ao_mpegpes.c
#define MSGTR_AO_MPEGPES_CantSetMixer "[AO MPEGPES] DVB audio kever belltsa sikertelen: %s.\n" 
#define MSGTR_AO_MPEGPES_UnsupSamplerate "[AO MPEGPES] %d Hz nem tmogatott, j mintavtelt prblok.\n"

// ao_null.c
// This one desn't even  have any mp_msg nor printf's?? [CHECK]

// ao_pcm.c
#define MSGTR_AO_PCM_FileInfo "[AO PCM] Fjl: %s (%s)\nPCM: Samplerate: %iHz Csatorna: %s Formtum: %s\n"
#define MSGTR_AO_PCM_HintInfo "[AO PCM] Info: Gyorsabb dump-ols a -vc null -vo null kapcsolval rhet el\n[AO PCM] Info: WAVE fjlok rshoz hasznld a -ao pcm:waveheader kapcsolt (alaprtelmezett)!\n"
#define MSGTR_AO_PCM_CantOpenOutputFile "[AO PCM] %s megnyitsa rsra nem sikerlt!\n"

// ao_sdl.c
#define MSGTR_AO_SDL_INFO "[AO SDL] Samplerate: %iHz Csatornk: %s Formtum: %s\n"
#define MSGTR_AO_SDL_DriverInfo "[AO SDL] %s audio vezrl hasznlata.\n"
#define MSGTR_AO_SDL_UnsupportedAudioFmt "[AO SDL] Nem tmogatott audio formtum: 0x%x.\n"
#define MSGTR_AO_SDL_CantInit "[AO SDL] SDL Audio inicializlsa nem sikerlt: %s\n"
#define MSGTR_AO_SDL_CantOpenAudio "[AO SDL] audio megnyitsa nem sikerlt: %s\n"

// ao_sgi.c
#define MSGTR_AO_SGI_INFO "[AO SGI] vezrls.\n"
#define MSGTR_AO_SGI_InitInfo "[AO SGI] init: Samplerate: %iHz Csatorna: %s Formtum: %s\n"
#define MSGTR_AO_SGI_InvalidDevice "[AO SGI] lejtszs: hibs eszkz.\n"
#define MSGTR_AO_SGI_CantSetParms_Samplerate "[AO SGI] init: setparams sikertelen: %s\nNem sikerlt belltani az elrt samplerate-et.\n"
#define MSGTR_AO_SGI_CantSetAlRate "[AO SGI] init: AL_RATE-et nem fogadta el a kivlasztott erforrs.\n"
#define MSGTR_AO_SGI_CantGetParms "[AO SGI] init: getparams sikertelen: %s\n"
#define MSGTR_AO_SGI_SampleRateInfo "[AO SGI] init: samplerate most mr %lf (elrt rta: %lf)\n"
#define MSGTR_AO_SGI_InitConfigError "[AO SGI] init: %s\n"
#define MSGTR_AO_SGI_InitOpenAudioFailed "[AO SGI] init: Nem tudom megnyitni az audio csatornt: %s\n"
#define MSGTR_AO_SGI_Uninit "[AO SGI] uninit: ...\n"
#define MSGTR_AO_SGI_Reset "[AO SGI] reset: ...\n"
#define MSGTR_AO_SGI_PauseInfo "[AO SGI] audio_pause: ...\n"
#define MSGTR_AO_SGI_ResumeInfo "[AO SGI] audio_resume: ...\n"

// ao_sun.c
#define MSGTR_AO_SUN_RtscSetinfoFailed "[AO SUN] rtsc: SETINFO sikertelen.\n"
#define MSGTR_AO_SUN_RtscWriteFailed "[AO SUN] rtsc: rs sikertelen.\n"
#define MSGTR_AO_SUN_CantOpenAudioDev "[AO SUN] %s audio eszkz nem elrhet, %s  -> nincs hang.\n"
#define MSGTR_AO_SUN_UnsupSampleRate "[AO SUN] audio_setup: a krtyd nem tmogat %d csatornt, %s, %d Hz samplerate-t.\n"
#define MSGTR_AO_SUN_CantUseSelect "[AO SUN]\n   ***  A hangkrtyd NEM tmogatja a select()-et ***\nFordtsd jra az MPlayer-t az #undef HAVE_AUDIO_SELECT sorral a config.h-ban !\n\n"
#define MSGTR_AO_SUN_CantReopenReset "[AO SUN]\nVgzetes hiba: *** NEM LEHET JRA MEGNYITNI / BELLTANI AZ AUDIO ESZKZT (%s) ***\n"

// ao_alsa5.c
#define MSGTR_AO_ALSA5_InitInfo "[AO ALSA5] alsa-init: krt formtum: %d Hz, %d csatorna, %s\n"
#define MSGTR_AO_ALSA5_SoundCardNotFound "[AO ALSA5] alsa-init: nem talltam hangkrtyt.\n"
#define MSGTR_AO_ALSA5_InvalidFormatReq "[AO ALSA5] alsa-init: hibs formtumot (%s) krtl - kimenet letiltva.\n"
#define MSGTR_AO_ALSA5_PlayBackError "[AO ALSA5] alsa-init: playback megnyitsi hiba: %s\n"
#define MSGTR_AO_ALSA5_PcmInfoError "[AO ALSA5] alsa-init: pcm info hiba: %s\n"
#define MSGTR_AO_ALSA5_SoundcardsFound "[AO ALSA5] alsa-init: %d hangkrtyt talltam, ezt hasznlom: %s\n"
#define MSGTR_AO_ALSA5_PcmChanInfoError "[AO ALSA5] alsa-init: pcm csatorna info hiba: %s\n"
#define MSGTR_AO_ALSA5_CantSetParms "[AO ALSA5] alsa-init: hiba a paramterek belltsakor: %s\n"
#define MSGTR_AO_ALSA5_CantSetChan "[AO ALSA5] alsa-init: hiba a csatorna belltsakor: %s\n"
#define MSGTR_AO_ALSA5_ChanPrepareError "[AO ALSA5] alsa-init: csatorna elksztsi hiba: %s\n"
#define MSGTR_AO_ALSA5_DrainError "[AO ALSA5] alsa-uninit: lejtszs drain hiba: %s\n"
#define MSGTR_AO_ALSA5_FlushError "[AO ALSA5] alsa-uninit: lejtszs rtsi hiba: %s\n"
#define MSGTR_AO_ALSA5_PcmCloseError "[AO ALSA5] alsa-uninit: pcm lezrsi hiba: %s\n"
#define MSGTR_AO_ALSA5_ResetDrainError "[AO ALSA5] alsa-reset: lejtszs drain hiba: %s\n"
#define MSGTR_AO_ALSA5_ResetFlushError "[AO ALSA5] alsa-reset: lejtszs rtsi hiba: %s\n"
#define MSGTR_AO_ALSA5_ResetChanPrepareError "[AO ALSA5] alsa-reset: csatorna elksztsi hiba: %s\n"
#define MSGTR_AO_ALSA5_PauseDrainError "[AO ALSA5] alsa-pause: lejtszs drain hiba: %s\n"
#define MSGTR_AO_ALSA5_PauseFlushError "[AO ALSA5] alsa-pause: lejtszs rtsi hiba: %s\n"
#define MSGTR_AO_ALSA5_ResumePrepareError "[AO ALSA5] alsa-resume: csatorna elksztsi hiba: %s\n"
#define MSGTR_AO_ALSA5_Underrun "[AO ALSA5] alsa-play: alsa underrun, folyam belltsa.\n"
#define MSGTR_AO_ALSA5_PlaybackPrepareError "[AO ALSA5] alsa-play: lejtszs elksztsi hiba: %s\n"
#define MSGTR_AO_ALSA5_WriteErrorAfterReset "[AO ALSA5] alsa-play: rsi hiba a bellts utn: %s - feladom.\n"
#define MSGTR_AO_ALSA5_OutPutError "[AO ALSA5] alsa-play: kimeneti hiba: %s\n"

// ao_plugin.c

#define MSGTR_AO_PLUGIN_InvalidPlugin "[AO PLUGIN] hibs plugin: %s\n"

// ======================= AF Audio Filters ================================

// libaf 

// af_ladspa.c

#define MSGTR_AF_LADSPA_AvailableLabels "hasznlhat cimkk"
#define MSGTR_AF_LADSPA_WarnNoInputs "FIGYELEM! Ennek a LADSPA pluginnak nincsenek audio bemenetei.\n  A bejv audi jelek elvesznek."
#define MSGTR_AF_LADSPA_ErrMultiChannel "A tbb-csatorns (>2) plugin (mg) nem tmogatott.\n  Csak a mono s sztereo plugin-okat hasznld."
#define MSGTR_AF_LADSPA_ErrNoOutputs "Ennek a LADSPA pluginnak nincsenek audi bemenetei."
#define MSGTR_AF_LADSPA_ErrInOutDiff "Klnbzik a LADSPA plugin audi bemenetek s kimenetek szma."
#define MSGTR_AF_LADSPA_ErrFailedToLoad "nem sikerlt betlteni"
#define MSGTR_AF_LADSPA_ErrNoDescriptor "A ladspa_descriptor() fggvny nem tallhat a megadott fggvnyknyvtr fjlban."
#define MSGTR_AF_LADSPA_ErrLabelNotFound "A cmke nem tallhat a plugin knyvtrban."
#define MSGTR_AF_LADSPA_ErrNoSuboptions "Nincs alopci megadva"
#define MSGTR_AF_LADSPA_ErrNoLibFile "Nincs knyvtrfjl megadva"
#define MSGTR_AF_LADSPA_ErrNoLabel "Nincs szr cmke megadva"
#define MSGTR_AF_LADSPA_ErrNotEnoughControls "Nincs elg vezrl megadva a parancssorban"
#define MSGTR_AF_LADSPA_ErrControlBelow "%s: A(z) #%d bemeneti vezrl a(z) %0.4f als hatr alatt van.\n"
#define MSGTR_AF_LADSPA_ErrControlAbove "%s: A(z) #%d bemeneti vezrl a(z) %0.4f fels hatr felett van.\n"

// format.c

#define MSGTR_AF_FORMAT_UnknownFormat "ismeretlen formtum "

// ========================== INPUT =========================================

// joystick.c

#define MSGTR_INPUT_JOYSTICK_Opening "Botkormny eszkz megnyitsa: %s\n"
#define MSGTR_INPUT_JOYSTICK_CantOpen "Nem sikerlt a(z) %s botkormny eszkzt megnyitni: %s\n"
#define MSGTR_INPUT_JOYSTICK_ErrReading "Hiba a botkormny eszkz olvassa kzben: %s\n"
#define MSGTR_INPUT_JOYSTICK_LoosingBytes "Botkormny: elvesztettnk %d bjtnyi adatot\n"
#define MSGTR_INPUT_JOYSTICK_WarnLostSync "Botkormny: figyelmeztet init esemny, elvesztettk a szinkront a vezrlvel\n"
#define MSGTR_INPUT_JOYSTICK_WarnUnknownEvent "Botkormny ismeretlen figyelmeztet esemny tpus: %d\n"

// input.c

#define MSGTR_INPUT_INPUT_ErrCantRegister2ManyCmdFds "Tl sok parancs fjl ler, nem sikerlt a(z) %d fjl ler regisztlsa.\n"
#define MSGTR_INPUT_INPUT_ErrCantRegister2ManyKeyFds "Tl sok gomb fjl ler, nem sikerlt a(z) %d fjl ler regisztlsa.\n"
#define MSGTR_INPUT_INPUT_ErrArgMustBeInt "%s parancs: %d argumentum nem egsz.\n"
#define MSGTR_INPUT_INPUT_ErrArgMustBeFloat "%s parancs: %d argumentum nem lebegpontos.\n"
#define MSGTR_INPUT_INPUT_ErrUnterminatedArg "%s parancs: %d argumentum lezratlan.\n"
#define MSGTR_INPUT_INPUT_ErrUnknownArg "Ismeretlen argumentum: %d\n"
#define MSGTR_INPUT_INPUT_Err2FewArgs "A(z) %s parancsnak legalbb %d argumentum kell, de csak %d-t talltunk eddig.\n"
#define MSGTR_INPUT_INPUT_ErrReadingCmdFd "Hiba a(z) %d parancs fjl ler olvassa kzben: %s\n"
#define MSGTR_INPUT_INPUT_ErrCmdBufferFullDroppingContent "%d parancs fjl ler buffere tele van: tartalom eldobsa\n"
#define MSGTR_INPUT_INPUT_ErrInvalidCommandForKey "Hibs parancs a(z) %s gombnl"
#define MSGTR_INPUT_INPUT_ErrSelect "Kivlasztsi hiba: %s\n"
#define MSGTR_INPUT_INPUT_ErrOnKeyInFd "Hiba a(z) %d gomb input fjl lerjban\n"
#define MSGTR_INPUT_INPUT_ErrDeadKeyOnFd "Halott gomb input a(z) %d fjl lernl\n"
#define MSGTR_INPUT_INPUT_Err2ManyKeyDowns "Tl sok gomblenyomsi esemny egy idben\n"
#define MSGTR_INPUT_INPUT_ErrOnCmdFd "Hiba a(z) %d parancs fjllerban\n"
#define MSGTR_INPUT_INPUT_ErrReadingInputConfig "Hiba a(z) %s input konfigurcis fjl olvassa kzben: %s\n"
#define MSGTR_INPUT_INPUT_ErrUnknownKey "Ismeretlen gomb '%s'\n"
#define MSGTR_INPUT_INPUT_ErrUnfinishedBinding "Nem befejezett hozzrendels: %s\n"
#define MSGTR_INPUT_INPUT_ErrBuffer2SmallForKeyName "A buffer tl kicsi ehhez a gomb nvhez: %s\n"
#define MSGTR_INPUT_INPUT_ErrNoCmdForKey "A(z) %s gombhoz nem tallhat parancs"
#define MSGTR_INPUT_INPUT_ErrBuffer2SmallForCmd "A buffer tl kicsi a(z) %s parancshoz\n"
#define MSGTR_INPUT_INPUT_ErrWhyHere "Mit keresnk mi itt?\n"
#define MSGTR_INPUT_INPUT_ErrCantInitJoystick "A bemeneti borkormny inicializlsa nem sikerlt\n"
#define MSGTR_INPUT_INPUT_ErrCantStatFile "Nem stat-olhat %s: %s\n"
#define MSGTR_INPUT_INPUT_ErrCantOpenFile "Nem nyithat meg %s: %s\n"

// ========================== LIBMPDEMUX ===================================

// url.c

#define MSGTR_MPDEMUX_URL_StringAlreadyEscaped "A karakterlnc mr escape-ltnek tnik az url_escape-ben %c%c1%c2\n"

// ai_alsa1x.c

#define MSGTR_MPDEMUX_AIALSA1X_CannotSetSamplerate "Nem llthat be a mintavteli rta\n"
#define MSGTR_MPDEMUX_AIALSA1X_CannotSetBufferTime "Nem llthat be a buffer id\n"
#define MSGTR_MPDEMUX_AIALSA1X_CannotSetPeriodTime "Nem llthat be a peridus id\n"

// ai_alsa1x.c / ai_alsa.c

#define MSGTR_MPDEMUX_AIALSA_PcmBrokenConfig "Hibs konfigurci ehhez a PCM-hez: nincs elrhet konfigurci\n"
#define MSGTR_MPDEMUX_AIALSA_UnavailableAccessType "Elrsi tpus nem hasznlhat\n"
#define MSGTR_MPDEMUX_AIALSA_UnavailableSampleFmt "Minta formtum nem elrhet\n"
#define MSGTR_MPDEMUX_AIALSA_UnavailableChanCount "Csatorna szmll nem elrhet - visszatrs az alaprtelmezetthez: %d\n"
#define MSGTR_MPDEMUX_AIALSA_CannotInstallHWParams "Sikertelen a hw paramterek belltsa:"
#define MSGTR_MPDEMUX_AIALSA_PeriodEqualsBufferSize "Nem hasznlhat a buffer mrettel egyez peridus (%u == %lu)\n"
#define MSGTR_MPDEMUX_AIALSA_CannotInstallSWParams "Sikertelen az sw paramterek belltsa:\n"
#define MSGTR_MPDEMUX_AIALSA_ErrorOpeningAudio "Hiba az audi megnyitsakor: %s\n"
#define MSGTR_MPDEMUX_AIALSA_AlsaStatusError "ALSA sttusz hiba: %s"
#define MSGTR_MPDEMUX_AIALSA_AlsaXRUN "ALSA xrun!!! (legalbb %.3f ms hosszan)\n"
#define MSGTR_MPDEMUX_AIALSA_AlsaStatus "ALSA Sttusz:\n"
#define MSGTR_MPDEMUX_AIALSA_AlsaXRUNPrepareError "ALSA xrun: elksztsi hiba: %s"
#define MSGTR_MPDEMUX_AIALSA_AlsaReadWriteError "ALSA olvass/rs hiba"

// ai_oss.c

#define MSGTR_MPDEMUX_AIOSS_Unable2SetChanCount "Sikertelen a csatorna szmll belltsa: %d\n"
#define MSGTR_MPDEMUX_AIOSS_Unable2SetStereo "Sikertelen a sztere belltsa: %d\n"
#define MSGTR_MPDEMUX_AIOSS_Unable2Open "'%s' nem nyithat meg: %s\n"
#define MSGTR_MPDEMUX_AIOSS_UnsupportedFmt "Nem tmogatott formtum\n"
#define MSGTR_MPDEMUX_AIOSS_Unable2SetAudioFmt "Az audi formtum nem llthat be."
#define MSGTR_MPDEMUX_AIOSS_Unable2SetSamplerate "A mintavteli rta nem llthat be: %d\n"
#define MSGTR_MPDEMUX_AIOSS_Unable2SetTrigger "A trigger nem llthat be: %d\n"
#define MSGTR_MPDEMUX_AIOSS_Unable2GetBlockSize "Nem sikerlt lekrdezni a blokkmretet!\n"
#define MSGTR_MPDEMUX_AIOSS_AudioBlockSizeZero "Az audi blokk mret nulla, belltva: %d!\n"
#define MSGTR_MPDEMUX_AIOSS_AudioBlockSize2Low "Az audi blokk mret tl kicsi, belltva: %d!\n"

// asfheader.c

#define MSGTR_MPDEMUX_ASFHDR_HeaderSizeOver1MB "VGZETES HIBA: fejlc mret nagyobb, mint 1 MB (%d)!\nKeresd meg az MPlayer ksztit s tltsd fel/kldd el ezt a fjlt.\n"
#define MSGTR_MPDEMUX_ASFHDR_HeaderMallocFailed "Nem sikerlt %d bjt lefoglalsa a fejlchez\n"
#define MSGTR_MPDEMUX_ASFHDR_EOFWhileReadingHeader "EOF az asf fejlc olvassa kzben, hibs/nem teljes fjl?\n"
#define MSGTR_MPDEMUX_ASFHDR_DVRWantsLibavformat "A DVR valsznleg csak libavformat-tal mkdik, prbld ki a -demuxer 35 -t problma esetn\n"
#define MSGTR_MPDEMUX_ASFHDR_NoDataChunkAfterHeader "Nincs adat rsz a fejlc utn!\n"
#define MSGTR_MPDEMUX_ASFHDR_AudioVideoHeaderNotFound "ASF: nem tallhat audi vagy vide fejlc - hibs fjl?\n"
#define MSGTR_MPDEMUX_ASFHDR_InvalidLengthInASFHeader "Hibs hossz az ASF fejlcben!\n"

// asf_mmst_streaming.c

#define MSGTR_MPDEMUX_MMST_WriteError "rsi hiba\n"
#define MSGTR_MPDEMUX_MMST_EOFAlert "\nRiad! eof\n"
#define MSGTR_MPDEMUX_MMST_PreHeaderReadFailed "el-fejlc olvass sikertelen\n"
#define MSGTR_MPDEMUX_MMST_InvalidHeaderSize "Hibs fejlc mret, feladom\n"
#define MSGTR_MPDEMUX_MMST_HeaderDataReadFailed "Fejlc adat olvassi hiba\n"
#define MSGTR_MPDEMUX_MMST_packet_lenReadFailed "packet_len olvassi hiba\n"
#define MSGTR_MPDEMUX_MMST_InvalidRTSPPacketSize "Hibs rtsp csomag mret, feladom\n"
#define MSGTR_MPDEMUX_MMST_CmdDataReadFailed "Parancs adat olvassi hiba\n"
#define MSGTR_MPDEMUX_MMST_HeaderObject "Fejlc objektum\n"
#define MSGTR_MPDEMUX_MMST_DataObject "Adat objektum\n"
#define MSGTR_MPDEMUX_MMST_FileObjectPacketLen "Fjl objektum, csomag mret = %d (%d)\n"
#define MSGTR_MPDEMUX_MMST_StreamObjectStreamID "Folyam objektum, folyam id: %d\n"
#define MSGTR_MPDEMUX_MMST_2ManyStreamID "Tl sok id, a folyam figyelmen kvl hagyva"
#define MSGTR_MPDEMUX_MMST_UnknownObject "Ismeretlen objektum\n"
#define MSGTR_MPDEMUX_MMST_MediaDataReadFailed "Mdia adat olvassi hiba\n"
#define MSGTR_MPDEMUX_MMST_MissingSignature "Hinyz alrs\n"
#define MSGTR_MPDEMUX_MMST_PatentedTechnologyJoke "Minden ksz. Ksznjk, hogy szabadalmazott technolgit alkalmaz mdit tltttl le.\n"
#define MSGTR_MPDEMUX_MMST_UnknownCmd "ismeretlen parancs %02x\n"
#define MSGTR_MPDEMUX_MMST_GetMediaPacketErr "get_media_packet hiba : %s\n"
#define MSGTR_MPDEMUX_MMST_Connected "Csatlakozva\n"

// asf_streaming.c

#define MSGTR_MPDEMUX_ASF_StreamChunkSize2Small "Ahhhh, stream_chunck mret tl kicsi: %d\n"
#define MSGTR_MPDEMUX_ASF_SizeConfirmMismatch "size_confirm hibs!: %d %d\n"
#define MSGTR_MPDEMUX_ASF_WarnDropHeader "Figyelmeztets : fejlc eldobva ????\n"
#define MSGTR_MPDEMUX_ASF_ErrorParsingChunkHeader "Hiba a fejlc chunk rtelmezsekor\n"
#define MSGTR_MPDEMUX_ASF_NoHeaderAtFirstChunk "Ne a fejlc legyen az els chunk !!!!\n"
#define MSGTR_MPDEMUX_ASF_BufferMallocFailed "Hiba, nem lehet alloklni a(z) %d bjtos buffert\n"
#define MSGTR_MPDEMUX_ASF_ErrReadingNetworkStream "Hiba a hlzati folyam olvassa kzben\n"
#define MSGTR_MPDEMUX_ASF_ErrChunk2Small "Hiba, a chunk tl kicsi\n"
#define MSGTR_MPDEMUX_ASF_ErrSubChunkNumberInvalid "Hiba, az al-chunk-ok szma hibs\n"
#define MSGTR_MPDEMUX_ASF_Bandwidth2SmallCannotPlay "Kicsi a svszlessg, a fjl nem lejtszhat!\n"
#define MSGTR_MPDEMUX_ASF_Bandwidth2SmallDeselectedAudio "A svszlessg tl kicsi, audi folyam kikapcsolva\n"
#define MSGTR_MPDEMUX_ASF_Bandwidth2SmallDeselectedVideo "A svszlessg tl kicsi, vide folyam kikapcsolva\n"
#define MSGTR_MPDEMUX_ASF_InvalidLenInHeader "Hibs hossz az ASF fejlcben!\n"
#define MSGTR_MPDEMUX_ASF_ErrReadingChunkHeader "Hiba a fejlc chunk olvassakor\n"
#define MSGTR_MPDEMUX_ASF_ErrChunkBiggerThanPacket "Hiba: chunk_size > packet_size\n"
#define MSGTR_MPDEMUX_ASF_ErrReadingChunk "Hiba a chunk olvassa kzben\n"
#define MSGTR_MPDEMUX_ASF_ASFRedirector "=====> ASF Redirector\n"
#define MSGTR_MPDEMUX_ASF_InvalidProxyURL "Hibs proxy URL\n"
#define MSGTR_MPDEMUX_ASF_UnknownASFStreamType "Ismeretlen asf folyam tpus\n"
#define MSGTR_MPDEMUX_ASF_Failed2ParseHTTPResponse "Sikertelen a HTTP vlasz rtelmezse\n"
#define MSGTR_MPDEMUX_ASF_ServerReturn "Szerver vlasz %d:%s\n"
#define MSGTR_MPDEMUX_ASF_ASFHTTPParseWarnCuttedPragma "ASF HTTP RTELMEZSI HIBA : %s pragma elvgva %d bjttl %d bjtig\n"
#define MSGTR_MPDEMUX_ASF_SocketWriteError "Socket rsi hiba : %s\n"
#define MSGTR_MPDEMUX_ASF_HeaderParseFailed "Sikertelen a fjlc rtelmezse\n"
#define MSGTR_MPDEMUX_ASF_NoStreamFound "Nem tallhat folyam\n"
#define MSGTR_MPDEMUX_ASF_UnknownASFStreamingType "Ismeretlen ASF folyam tpus\n"
#define MSGTR_MPDEMUX_ASF_InfoStreamASFURL "STREAM_ASF, URL: %s\n"
#define MSGTR_MPDEMUX_ASF_StreamingFailed "Sikertelen, kilps\n"

// audio_in.c

#define MSGTR_MPDEMUX_AUDIOIN_ErrReadingAudio "\nHiba az audi olvassakor: %s\n"
#define MSGTR_MPDEMUX_AUDIOIN_XRUNSomeFramesMayBeLeftOut "Visszatrs a cross-run-bl, nhny kpkocka kimaradhatott!\n"
#define MSGTR_MPDEMUX_AUDIOIN_ErrFatalCannotRecover "Vgzetes hiba, nem lehet visszatrni!\n"
#define MSGTR_MPDEMUX_AUDIOIN_NotEnoughSamples "\nNincs elg audi minta!\n"

// aviheader.c

#define MSGTR_MPDEMUX_AVIHDR_EmptyList "** res lista?!\n"
#define MSGTR_MPDEMUX_AVIHDR_FoundMovieAt "Film megtallva: 0x%X - 0x%X\n"
#define MSGTR_MPDEMUX_AVIHDR_FoundBitmapInfoHeader "'bih' megtallva, %u bjt %d bjtbl\n"
#define MSGTR_MPDEMUX_AVIHDR_RegeneratingKeyfTableForMPG4V1 "A kulcs kpkocka tbla jragenerlva az M$ mpg4v1 videhoz\n"
#define MSGTR_MPDEMUX_AVIHDR_RegeneratingKeyfTableForDIVX3 "Kulcs kpkocka tbla jragenerlsa a DIVX3 videhoz\n"
#define MSGTR_MPDEMUX_AVIHDR_RegeneratingKeyfTableForMPEG4 "Kulcs kpkocka tbla jragenerlsa az MPEG4 videhoz\n"
#define MSGTR_MPDEMUX_AVIHDR_FoundWaveFmt "'wf' megtallva, %d bjt %d bjtbl\n"
#define MSGTR_MPDEMUX_AVIHDR_FoundAVIV2Header "AVI: dmlh megtallva (size=%d) (total_frames=%d)\n"
#define MSGTR_MPDEMUX_AVIHDR_ReadingIndexBlockChunksForFrames "INDEX blokk olvassa, %d chunk %d kpkockhoz (fpos=%"PRId64")\n"
#define MSGTR_MPDEMUX_AVIHDR_AdditionalRIFFHdr "Kiegszt RIFF fejlc...\n"
#define MSGTR_MPDEMUX_AVIHDR_WarnNotExtendedAVIHdr "** figyelmeztets: ez nem kiterjesztett AVI fejlc..\n"
#define MSGTR_MPDEMUX_AVIHDR_BrokenChunk "Hibs chunk?  chunksize=%d  (id=%.4s)\n"
#define MSGTR_MPDEMUX_AVIHDR_BuildingODMLidx "AVI: ODML: odml index felptse (%d superindexchunks)\n"
#define MSGTR_MPDEMUX_AVIHDR_BrokenODMLfile "AVI: ODML: Hibs (nem teljes?) fjlt talltam. Tradcionlis index hasznlata\n"
#define MSGTR_MPDEMUX_AVIHDR_CantReadIdxFile "A(z) %s index fjl nem olvashat: %s\n"
#define MSGTR_MPDEMUX_AVIHDR_NotValidMPidxFile "%s nem rvnyes MPlayer index fjl\n"
#define MSGTR_MPDEMUX_AVIHDR_FailedMallocForIdxFile "Nem lehet memrit foglalni az index adatoknak %s-bl\n"
#define MSGTR_MPDEMUX_AVIHDR_PrematureEOF "Korai index fjlvg %s fjlban\n"
#define MSGTR_MPDEMUX_AVIHDR_IdxFileLoaded "Betlttt index fjl: %s\n"
#define MSGTR_MPDEMUX_AVIHDR_GeneratingIdx "Index generlsa: %3lu %s     \r"
#define MSGTR_MPDEMUX_AVIHDR_IdxGeneratedForHowManyChunks "AVI: Index tbla legenerlva %d chunk-hoz!\n"
#define MSGTR_MPDEMUX_AVIHDR_Failed2WriteIdxFile "Nem sikerlt a(z) %s index fjl rsa: %s\n"
#define MSGTR_MPDEMUX_AVIHDR_IdxFileSaved "Elmentett index fjl: %s\n"

// cache2.c

#define MSGTR_MPDEMUX_CACHE2_NonCacheableStream "\rEz a folyam nem cache-elhet.\n"
#define MSGTR_MPDEMUX_CACHE2_ReadFileposDiffers "!!! read_filepos klnbzik!!! jelentsd ezt a hibt...\n"

// cdda.c

#define MSGTR_MPDEMUX_CDDA_CantOpenCDDADevice "Nem nyithat meg a CDDA eszkz.\n"
#define MSGTR_MPDEMUX_CDDA_CantOpenDisc "Nem nyithat meg a lemez.\n"
#define MSGTR_MPDEMUX_CDDA_AudioCDFoundWithNTracks "Audi CD-t talltam %ld svval.\n"

// cddb.c

#define MSGTR_MPDEMUX_CDDB_FailedToReadTOC "Hiba a TOC olvassa kzben.\n"
#define MSGTR_MPDEMUX_CDDB_FailedToOpenDevice "Hiba a(z) %s eszkz megnyitsakor.\n"
#define MSGTR_MPDEMUX_CDDB_NotAValidURL "Hibs URL\n"
#define MSGTR_MPDEMUX_CDDB_FailedToSendHTTPRequest "HTTP krs elkldse nem sikerlt.\n"
#define MSGTR_MPDEMUX_CDDB_FailedToReadHTTPResponse "HTTP vlasz olvassa nem sikerlt.\n"
#define MSGTR_MPDEMUX_CDDB_HTTPErrorNOTFOUND "Nem tallhat.\n"
#define MSGTR_MPDEMUX_CDDB_HTTPErrorUnknown "Ismeretlen hibakd\n"
#define MSGTR_MPDEMUX_CDDB_NoCacheFound "Nem talltam cache-t.\n"
#define MSGTR_MPDEMUX_CDDB_NotAllXMCDFileHasBeenRead "Nem minden xmcd fjl lett elolvasva.\n"
#define MSGTR_MPDEMUX_CDDB_FailedToCreateDirectory "Sikertelen a(z) %s knyvtr ltrehozsa.\n"
#define MSGTR_MPDEMUX_CDDB_NotAllXMCDFileHasBeenWritten "Nem minden xmcd fjl lett kirva.\n"
#define MSGTR_MPDEMUX_CDDB_InvalidXMCDDatabaseReturned "Hibs xmcd adatbzis fjl rkezett vissza.\n"
#define MSGTR_MPDEMUX_CDDB_UnexpectedFIXME "Nem vrt FIXME\n"
#define MSGTR_MPDEMUX_CDDB_UnhandledCode "Kezeletlen kd\n"
#define MSGTR_MPDEMUX_CDDB_UnableToFindEOL "Nem tallhat a sor vge\n"
#define MSGTR_MPDEMUX_CDDB_ParseOKFoundAlbumTitle "rtelmezs OK, talltam: %s\n"
#define MSGTR_MPDEMUX_CDDB_AlbumNotFound "Album nem tallhat\n"
#define MSGTR_MPDEMUX_CDDB_ServerReturnsCommandSyntaxErr "Szerver vlasza: Parancs szintaxis hibs\n"
#define MSGTR_MPDEMUX_CDDB_NoSitesInfoAvailable "Nincs elrhet oldal informci\n"
#define MSGTR_MPDEMUX_CDDB_FailedToGetProtocolLevel "Sikertelen a protokol szint lekrdezse\n"
#define MSGTR_MPDEMUX_CDDB_NoCDInDrive "Nincs CD a meghajtban\n"

// cue_read.c

#define MSGTR_MPDEMUX_CUEREAD_UnexpectedCuefileLine "[bincue] Nem vrt cuefjl sor: %s\n"
#define MSGTR_MPDEMUX_CUEREAD_BinFilenameTested "[bincue] tesztelt bin fjlnv: %s\n"
#define MSGTR_MPDEMUX_CUEREAD_CannotFindBinFile "[bincue] Nem tallhat a bin fjl - feladom\n"
#define MSGTR_MPDEMUX_CUEREAD_UsingBinFile "[bincue] %s bin fjl hasznlata\n"
#define MSGTR_MPDEMUX_CUEREAD_UnknownModeForBinfile "[bincue] Ismeretlen md a binfjlhoz. Nem szabadna megtrtnnie. Megszakts.\n"
#define MSGTR_MPDEMUX_CUEREAD_CannotOpenCueFile "[bincue] %s nem nyithat meg\n"
#define MSGTR_MPDEMUX_CUEREAD_ErrReadingFromCueFile "[bincue] Hiba %s fjlbl trtn olvasskor\n"
#define MSGTR_MPDEMUX_CUEREAD_ErrGettingBinFileSize "[bincue] Hiba a bin fjl mretnek lekrdezsekor\n"
#define MSGTR_MPDEMUX_CUEREAD_InfoTrackFormat "sv %02d:  formtum=%d  %02d:%02d:%02d\n"
#define MSGTR_MPDEMUX_CUEREAD_UnexpectedBinFileEOF "[bincue] nem vrt vge a bin fjlnak\n"
#define MSGTR_MPDEMUX_CUEREAD_CannotReadNBytesOfPayload "[bincue] Nem olvashat %d bjtnyi payload\n"
#define MSGTR_MPDEMUX_CUEREAD_CueStreamInfo_FilenameTrackTracksavail "CUE stream_open, fjlnv=%s, sv=%d, elrhet svok: %d -> %d\n"

// network.c

#define MSGTR_MPDEMUX_NW_UnknownAF "Ismeretlen cmosztly: %d\n"
#define MSGTR_MPDEMUX_NW_ResolvingHostForAF "%s feloldsa erre: %s...\n"
#define MSGTR_MPDEMUX_NW_CantResolv "Nem oldhat fel nv %s -hez: %s\n"
#define MSGTR_MPDEMUX_NW_ConnectingToServer "Csatlakozs a(z) %s[%s] szerverhez: %d...\n"
#define MSGTR_MPDEMUX_NW_CantConnect2Server "Sikertelen csatlakozs a szerverhez %s -sel\n"
#define MSGTR_MPDEMUX_NW_SelectFailed "Kivlaszts sikertelen.\n"
#define MSGTR_MPDEMUX_NW_ConnTimeout "Idtllps a csatlakozskor.\n"
#define MSGTR_MPDEMUX_NW_GetSockOptFailed "getsockopt sikertelen: %s\n"
#define MSGTR_MPDEMUX_NW_ConnectError "Csatlakozsi hiba: %s\n"
#define MSGTR_MPDEMUX_NW_InvalidProxySettingTryingWithout "Hibs proxy bellts... Megprblom proxy nlkl.\n"
#define MSGTR_MPDEMUX_NW_CantResolvTryingWithoutProxy "Nem oldhat fel a tvoli hosztnv az AF_INET-hez. Megprblom proxy nlkl.\n"
#define MSGTR_MPDEMUX_NW_ErrSendingHTTPRequest "Hiba a HTTP krs kldsekor: nem kldte el az sszes krst.\n"
#define MSGTR_MPDEMUX_NW_ReadFailed "Olvass sikertelen.\n"
#define MSGTR_MPDEMUX_NW_Read0CouldBeEOF "http_read_response 0-t olvasott, (pl. EOF)\n"
#define MSGTR_MPDEMUX_NW_AuthFailed "Azonosts sikertelen. Krlek hasznld a -user s -passwd kapcsolkat az\n"\
"azonost/jelsz megadshoz URL listknl, vagy rd az albbi formban az URL-t:\n"\
"http://usernev:jelszo@hostnev/fajl\n"
#define MSGTR_MPDEMUX_NW_AuthRequiredFor "Azonosts szksges ehhez: %s\n"
#define MSGTR_MPDEMUX_NW_AuthRequired "Azonosts szksges.\n"
#define MSGTR_MPDEMUX_NW_NoPasswdProvidedTryingBlank "Nincs jelsz megadva, res jelszt prblok.\n"
#define MSGTR_MPDEMUX_NW_ErrServerReturned "Szerver vlasz %d: %s\n"
#define MSGTR_MPDEMUX_NW_CacheSizeSetTo "Cache mret belltva %d KByte-ra\n"

// ========================== LIBMPMENU ===================================

// libmenu/menu.c
#define MSGTR_LIBMENU_SyntaxErrorAtLine "[MENU] Szintaktikus hiba ebben a sorban: %d\n"
#define MSGTR_LIBMENU_MenuDefinitionsNeedANameAttrib "[MENU] A men defincikhoz nevestett attribtum kell (%d. sor)\n"
#define MSGTR_LIBMENU_BadAttrib "[MENU] Hibs attribtum %s=%s a(z) '%s' menben a(z) %d. sorban\n"
#define MSGTR_LIBMENU_UnknownMenuType "[MENU] Ismeretlen men tpus: '%s' a(z) %d. sorban\n"
#define MSGTR_LIBMENU_CantOpenConfigFile "[MENU] A men konfigurcis fjl nem nyithat meg: %s\n"
#define MSGTR_LIBMENU_ConfigFileIsTooBig "[MENU] A konfigurcis fjl tl nagy (> %d KB)\n"
#define MSGTR_LIBMENU_ConfigFileIsEmpty "[MENU] A konfigurcis fjl res\n"
#define MSGTR_LIBMENU_MenuNotFound "[MENU] A(z) % men nem tallhat.\n"
#define MSGTR_LIBMENU_MenuInitFailed "[MENU] '%s' men: init sikertelen\n"
#define MSGTR_LIBMENU_UnsupportedOutformat "[MENU] Nem tmogatott kimeneti formtum!!!!\n"

// libmenu/menu_cmdlist.c
#define MSGTR_LIBMENU_NoEntryFoundInTheMenuDefinition "[MENU] Nem tallhat bejegyzs a men definciban.\n"
#define MSGTR_LIBMENU_ListMenuEntryDefinitionsNeedAName "[MENU] A lista menelemek definciihoz kell egy nv (%d. sor).\n"
#define MSGTR_LIBMENU_ListMenuNeedsAnArgument "[MENU] A lista menhz egy argumentum kell.\n"

// libmenu/menu_console.c
#define MSGTR_LIBMENU_WaitPidError "[MENU] Waitpid hiba: %s.\n"
#define MSGTR_LIBMENU_SelectError "[MENU] Kivlasztsi hiba.\n"
#define MSGTR_LIBMENU_ReadErrorOnChilds "[MENU] Olvassi hiba a gyerekben: %s.\n"
#define MSGTR_LIBMENU_ConsoleRun "[MENU] Konzol futtats: %s ...\n"
#define MSGTR_LIBMENU_AChildIsAlreadyRunning "[MENU] Egy gyermek mr fut.\n"
#define MSGTR_LIBMENU_ForkFailed "[MENU] Fork sikertelen !!!\n"
#define MSGTR_LIBMENU_WriteError "[MENU] rsi hiba.\n"

// libmenu/menu_filesel.c
#define MSGTR_LIBMENU_OpendirError "[MENU] Opendir hiba: %s.\n"
#define MSGTR_LIBMENU_ReallocError "[MENU] Realloc hiba: %s.\n"
#define MSGTR_LIBMENU_MallocError "[MENU] Memria foglalsi hiba: %s.\n"
#define MSGTR_LIBMENU_ReaddirError "[MENU] Readdir hiba: %s.\n"
#define MSGTR_LIBMENU_CantOpenDirectory "[MENU] A(z) %s knyvtr nem nyithat meg\n"

// libmenu/menu_param.c
#define MSGTR_LIBMENU_NoEntryFoundInTheMenuDefinition "[MENU] A men definciban nincs bejegyzs.\n"
#define MSGTR_LIBMENU_SubmenuDefinitionNeedAMenuAttribut "[MENU] Az almen defincikba kell egy 'menu' attribtum.\n"
#define MSGTR_LIBMENU_PrefMenuEntryDefinitionsNeed "[MENU] Pref men bejegyzs definciihoz egy j 'property' attribtum kell (%d. sor).\n"
#define MSGTR_LIBMENU_PrefMenuNeedsAnArgument "[MENU] Pref menhz egy argumentum kell.\n"

// libmenu/menu_pt.c
#define MSGTR_LIBMENU_CantfindTheTargetItem "[MENU] Nem tallhat a cl elem ????\n"
#define MSGTR_LIBMENU_FailedToBuildCommand "[MENU] Nem sikerlt a parancs felptse: %s.\n"

// libmenu/menu_txt.c
#define MSGTR_LIBMENU_MenuTxtNeedATxtFileName "[MENU] A szveges menhz egy txt fjl nv kell (param file).\n"
#define MSGTR_LIBMENU_MenuTxtCantOpen "[MENU] Nem nyithat meg: %s.\n"
#define MSGTR_LIBMENU_WarningTooLongLineSplitting "[MENU] Figyelem, tl hozz sor. Elvgom.\n"
#define MSGTR_LIBMENU_ParsedLines "[MENU] %d sor rtelmezve.\n"

// libmenu/vf_menu.c
#define MSGTR_LIBMENU_UnknownMenuCommand "[MENU] Ismeretlen parancs: '%s'.\n"
#define MSGTR_LIBMENU_FailedToOpenMenu "[MENU] Sikertelen a men megnyitsa: '%s'.\n"

// ========================== LIBMPCODECS ===================================

// libmpcodecs/ad_libdv.c
#define MSGTR_MPCODECS_AudioFramesizeDiffers "[AD_LIBDV] Figyelem! Az audi keretmret klnbz! read=%d  hdr=%d.\n"

// libmpcodecs/vd_dmo.c vd_dshow.c vd_vfw.c
#define MSGTR_MPCODECS_CouldntAllocateImageForCinepakCodec "[VD_DMO] Nem foglalhat le a kp a cinepak codec-hez.\n"

// libmpcodecs/vd_ffmpeg.c
#define MSGTR_MPCODECS_XVMCAcceleratedCodec "[VD_FFMPEG] XVMC-vel gyorstott codec.\n"
#define MSGTR_MPCODECS_ArithmeticMeanOfQP "[VD_FFMPEG] QP aritmetikus kzepe: %2.4f, QP harmonikus kzepe: %2.4f\n"
#define MSGTR_MPCODECS_DRIFailure "[VD_FFMPEG] DRI hiba.\n"
#define MSGTR_MPCODECS_CouldntAllocateImageForCodec "[VD_FFMPEG] Nem sikerlt a kp lefoglalsa a codec-hez.\n"
#define MSGTR_MPCODECS_XVMCAcceleratedMPEG2 "[VD_FFMPEG] XVMC-vel gyorstott MPEG2.\n"
#define MSGTR_MPCODECS_TryingPixfmt "[VD_FFMPEG] pixfmt=%d kiprblsa.\n"
#define MSGTR_MPCODECS_McGetBufferShouldWorkOnlyWithXVMC "[VD_FFMPEG] Az mc_get_buffer csak XVMC gyorstssal mkdik!!"
#define MSGTR_MPCODECS_UnexpectedInitVoError "[VD_FFMPEG] Vratlan init_vo hiba.\n"
#define MSGTR_MPCODECS_UnrecoverableErrorRenderBuffersNotTaken "[VD_FFMPEG] Helyrehozhatatlan hiba, a render bufferek nincsenek meg.\n"
#define MSGTR_MPCODECS_OnlyBuffersAllocatedByVoXvmcAllowed "[VD_FFMPEG] Csak a vo_xvmc ltal lefoglalt bufferek hasznlhatak.\n"

// libmpcodecs/ve_lavc.c
#define MSGTR_MPCODECS_HighQualityEncodingSelected "[VE_LAVC] Nagyon j minsg kdols kivlasztva (nem vals idej)!\n"
#define MSGTR_MPCODECS_UsingConstantQscale "[VE_LAVC] Konstans qscale = %f (VBR) hasznlata.\n"

// libmpcodecs/ve_raw.c
#define MSGTR_MPCODECS_OutputWithFourccNotSupported "[VE_RAW] Nyers kimenet fourcc-vel [%x] nem tmogatott!\n"
#define MSGTR_MPCODECS_NoVfwCodecSpecified "[VE_RAW] A krt VfW codec nincs megadva!!\n"

// libmpcodecs/vf_crop.c
#define MSGTR_MPCODECS_CropBadPositionWidthHeight "[CROP] Hibs pozci/szlessg/magassg - a levgott terlet az eredetin kvl van!\n"

// libmpcodecs/vf_cropdetect.c
#define MSGTR_MPCODECS_CropArea "[CROP] Vgsi terlet: X: %d..%d  Y: %d..%d  (-vf crop=%d:%d:%d:%d).\n"

// libmpcodecs/vf_format.c, vf_palette.c, vf_noformat.c
#define MSGTR_MPCODECS_UnknownFormatName "[VF_FORMAT] Ismeretlen formtumnv: '%s'.\n"

// libmpcodecs/vf_framestep.c vf_noformat.c vf_palette.c vf_tile.c
#define MSGTR_MPCODECS_ErrorParsingArgument "[VF_FRAMESTEP] Hiba az argumentum rtelmezsekor.\n"

// libmpcodecs/ve_vfw.c
#define MSGTR_MPCODECS_CompressorType "Tmrt tpusa: %.4lx\n"
#define MSGTR_MPCODECS_CompressorSubtype "Tmrt altpusa: %.4lx\n"
#define MSGTR_MPCODECS_CompressorFlags "Tmrt flag-jei: %lu, %lu verzi, ICM verzi: %lu\n"
#define MSGTR_MPCODECS_Flags "Flag-ek:"
#define MSGTR_MPCODECS_Quality " minsg"

// libmpcodecs/vf_expand.c
#define MSGTR_MPCODECS_FullDRNotPossible "A teljes DR nem lehetsges, inkbb SLICES-t prblok helyette!\n"
#define MSGTR_MPCODECS_WarnNextFilterDoesntSupportSlices  "FIGYELEM! A kvetkez szr nem tmogatja a SLICES-t, kszlj a sig11-re...\n"
#define MSGTR_MPCODECS_FunWhydowegetNULL "Mirt kaptunk itt NULL-t??\n"

// libmpcodecs/vf_fame.c
#define MSGTR_MPCODECS_FatalCantOpenlibFAME "VGZETES: a libFAME nem nyithat meg!\n"

// libmpcodecs/vf_test.c, vf_yuy2.c, vf_yvu9.c
#define MSGTR_MPCODECS_WarnNextFilterDoesntSupport "%s nem tmogatott a kvetkez szrben/vo-ban :(\n"
